@@ -23,11 +23,14 @@
 # along with Shinken.  If not, see <http://www.gnu.org/licenses/>.
 
 import cPickle
+import itertools
 import json
+import logging
 import os
 import shutil
 import socket
 import sys
+import threading
 import time
 import traceback
 from Queue import Empty
@@ -35,22 +38,27 @@ from multiprocessing import Process
 
 import shinken.misc.configuration_error_log as arbiter_configuration_messages
 from shinken.brok import Brok, PersistantBrok
+from shinken.component.arbiter.monitoring_start_time_component import MonitoringStartTimeComponent
 from shinken.configuration_incarnation import ConfigurationIncarnation
 from shinken.daemon import Daemon, Interface, IStatsInterface
 from shinken.dispatcher import Dispatcher
 from shinken.external_command import ExternalCommand
 from shinken.external_command import ExternalCommandManager
+from shinken.inter_daemon_message import InterDaemonMessage
 from shinken.log import logger, get_chapter_string, LoggerFactory
 from shinken.misc.type_hint import TYPE_CHECKING
-from shinken.objects.config import Config
+from shinken.objects.config import Config, OLD_ARBITER_RETENTION_JSON, REALM_RETENTION_JSON
 from shinken.runtime_stats.cpu_stats import cpu_stats_helper
 from shinken.runtime_stats.threads_dumper import WatchDogThreadDumper
 from shinken.safepickle import SafeUnpickler
 from shinken.util import jsonify_r, set_process_name
+from shinkensolutions.system_tools import set_ownership
 from shinkensolutions.arbiter_configuration_messages import start_write_arbiter_messages, flush_arbiter_message_buffer, COMMON_FILE_NAME, end_write_arbiter_messages, write_final_json
 
 if TYPE_CHECKING:
-    from shinken.misc.type_hint import Any, Dict, Optional
+    from shinken.misc.type_hint import Optional, Dict, Any, List
+    from shinken.objects.realm import Realm
+    from shinken.satellitelink import SatelliteLink
 
 raw_logger = LoggerFactory.get_logger()
 logger_perf = raw_logger.get_sub_part(u'PERF', part_name_size=4)
@@ -66,7 +74,7 @@ CHAPTER_CONFIGURATION = get_chapter_string('CONFIGURATION')
 
 # Interface for the other Arbiter
 # It connects, and together we decide who's the Master and who's the Slave, etc.
-# Here is a also a function to get a new conf from the master
+# Here is also a function to get a new conf from the master
 class IForArbiter(Interface):
     def get_daemon_infos(self):
         to_return = {
@@ -353,15 +361,18 @@ class Arbiter(Daemon):
         # Now tab for external_commands
         self.external_commands = []
         
+        self.messages_from_satellites_lock = threading.RLock()
+        self.messages_from_satellites = []  # type: List[InterDaemonMessage]
+        self.messages_to_satellites_lock = threading.RLock()
+        self.messages_to_satellites = []  # type: List[InterDaemonMessage]
         
         # Used to work out if we must still be alive or not
         self.must_run = True
         self._is_retention_load_already_try = False  # Only load retention one time
         
-        self.uri_arb = None
         self.interface = IForArbiter(self)
-        self.uri_stats = None
-        self.istats = IStats(self)
+        self._add_http_interface(IStats(self))
+        self._add_http_interface(self.interface)
         
         self.conf = Config()
         self.trace = None
@@ -372,13 +383,14 @@ class Arbiter(Daemon):
         
         # We are creating the configuration incarnation that will be given
         # with ALL the configuration, but currently we just don't know
-        # our own name so we will give it later
+        # our own name, so we will give it later
         self.configuration_incarnation = ConfigurationIncarnation()
         
         # Architecture name: name of the Shinken Enterprise installation
         # across all the nodes, used to detect several shinken enteprise
         # installations that are crossed, like testing giving conf to a prod node
         self._architecture_name = None
+        self.monitoring_start_time_component = None
     
     
     # Currently, the architecture name
@@ -430,7 +442,7 @@ class Arbiter(Daemon):
         self.trace = {
             'master_arbiter_uuid': self.conf.master_arbiter_uuid,
             'expire_period'      : self.me.check_interval * self.me.max_check_attempts,  # default value, will be changed for every daemon
-            'check_interval'     : self.me.check_interval,  # only for daemon with a version < 02.07.05-Patched-05 (02.07.06) do not use this value anymore use expire_period instead
+            'check_interval'     : self.me.check_interval,  # only for daemon with a version < 02.07.05-Patched-05 (02.07.06) do not use this value anymore, use expire_period instead
             'spare'              : self.me.spare,
             'name'               : self.me.arbiter_name,
             'uri'                : uri,
@@ -460,7 +472,7 @@ class Arbiter(Daemon):
         self.broks[b.id] = b
     
     
-    # We must push our broks to the broker because it's stupid to make a crossing connection
+    # We must push our broks to the broker because it's stupid to make a crossing connection,
     # so we find the broker responsible for our broks, and we send it to him
     def push_broks_to_broker(self):
         for brk in self.conf.brokers:
@@ -476,8 +488,7 @@ class Arbiter(Daemon):
     
     # We must take external_commands from all satellites like brokers, pollers, reactionners or receivers
     def get_external_commands_from_satellites(self):
-        sat_lists = [self.conf.brokers, self.conf.receivers,
-                     self.conf.pollers, self.conf.reactionners]
+        sat_lists = [self.conf.brokers, self.conf.receivers, self.conf.pollers, self.conf.reactionners]
         for lst in sat_lists:
             for sat in lst:
                 # Get only if alive of course
@@ -487,6 +498,114 @@ class Arbiter(Daemon):
                         self.external_commands.append(new_cmd)
     
     
+    def get_messages_from_satellites(self):
+        # type: () -> None
+        logger_message = LoggerFactory.get_logger(u'MANAGE INTER DAEMON MESSAGE')
+        for satellite in itertools.chain(self.conf.brokers, self.conf.receivers, self.conf.pollers, self.conf.reactionners):
+            # # Get only if alive of course
+            # if not satellite.alive:
+            #     continue
+            
+            t0 = time.time()
+            messages = satellite.get_messages()
+            with self.messages_from_satellites_lock:
+                self.messages_from_satellites.extend(messages)
+            
+            if messages:
+                logger_message.info(u'Got 〖%s〗 new messages from 〖%s〗 in 〖%s〗' % (len(messages), satellite.get_name(), logger_message.format_chrono(t0)))
+                if logger_message.is_debug():
+                    for m in messages:
+                        logger_message.debug(u'Got message 〖%s〗' % (m.get_message_info()))
+        self._process_received_messages_from_satellites()
+    
+    
+    def _process_received_messages_from_satellites(self):
+        # type: () -> None
+        
+        logger_message = LoggerFactory.get_logger(u'MANAGE INTER DAEMON MESSAGE')
+        
+        with self.messages_from_satellites_lock:
+            if not self.messages_from_satellites:
+                return
+            messages_from_satellites = self.messages_from_satellites
+            self.messages_from_satellites = []
+        
+        nb_message_inter_daemon = len(messages_from_satellites)
+        process_messages = []
+        for inter_daemon_message in messages_from_satellites:
+            if inter_daemon_message.message_to.daemon_name != self.name:
+                continue
+            if inter_daemon_message.message_to.module_name == u'':
+                # Message is for our daemon, not its modules
+                self.handle_received_inter_daemon_message_for_arbiter(inter_daemon_message)
+                process_messages.append(inter_daemon_message)
+                continue
+            
+            # OK : it's a message for one type of module, we give it to all the modules concerned
+            for module in self.modules_manager.get_all_alive_instances():
+                if inter_daemon_message.message_to.module_name == module.name:
+                    module.handle_push_messages_by_arbiter(inter_daemon_message)
+                    process_messages.append(inter_daemon_message)
+        
+        for process_message in process_messages:
+            logger_message.debug(u'Processed message from satellites:〖%s〗' % process_message.get_message_info())
+            messages_from_satellites.remove(process_message)
+        
+        logger_message.info(u'Message from satellites:〖%s〗 processed:〖%s〗 remaining:〖%s〗' % (nb_message_inter_daemon, len(process_messages), len(messages_from_satellites)))
+        if logger_message.is_debug():
+            for remaining_message in messages_from_satellites:
+                logger_message.debug(u'Remaining message from arbiter:〖%s〗' % remaining_message.get_message_info())
+        
+        with self.messages_from_satellites_lock:
+            self.messages_from_satellites.extend(messages_from_satellites)
+    
+    
+    def handle_received_inter_daemon_message_for_arbiter(self, inter_daemon_message):
+        # type: (InterDaemonMessage) -> None
+        
+        if inter_daemon_message.message_type == u'ping':
+            self.send_message_to_satellites(InterDaemonMessage(u'pong', message_to=inter_daemon_message.message_from, message_from=inter_daemon_message.message_to, data={}))
+            return
+        
+        if inter_daemon_message.message_type == u'response_monitoring_start_time':
+            self.monitoring_start_time_component.handle_response_monitoring_start_time(inter_daemon_message)
+    
+    
+    def send_messages_to_satellites(self):
+        # type: () -> None
+        logger_message = LoggerFactory.get_logger(u'MANAGE INTER DAEMON MESSAGE')
+        for satellite in itertools.chain(self.conf.brokers, self.conf.receivers, self.conf.pollers, self.conf.reactionners):  # type: SatelliteLink
+            # Get only if alive of course
+            if not satellite.alive or not satellite.is_activated():
+                continue
+            
+            t0 = time.time()
+            with self.messages_to_satellites_lock:
+                messages_to_send = [m for m in self.messages_to_satellites if self._can_send_message(satellite, m)]
+                for m in messages_to_send:
+                    self.messages_to_satellites.remove(m)
+            satellite.send_messages(messages_to_send)
+            
+            if messages_to_send:
+                logger_message.info(u'Send 〖%s〗 messages to 〖%s〗 in 〖%s〗' % (len(messages_to_send), satellite.get_name(), logger_message.format_chrono(t0)))
+                if logger_message.is_debug():
+                    for m in messages_to_send:
+                        logger_message.debug(u'Send messages 〖%s〗' % (m.get_message_info()))
+    
+    
+    @staticmethod
+    def _can_send_message(satellite, message):
+        # type: (SatelliteLink, InterDaemonMessage) -> bool
+        message_to = message.message_to
+        return message_to.daemon_name == satellite.get_name() and (not message_to.module_name or message_to.module_name in [m.get_name() for m in satellite.modules])
+    
+    
+    def send_message_to_satellites(self, inter_daemon_message):
+        # type: (InterDaemonMessage) -> None
+        with self.messages_to_satellites_lock:
+            self.messages_to_satellites.append(inter_daemon_message)
+    
+    
     # Our links to satellites can raise broks. We must send them
     def get_broks_from_satellitelinks(self):
         tabs = [self.conf.brokers, self.conf.schedulers,
@@ -511,7 +630,7 @@ class Arbiter(Daemon):
     
     
     def get_daemon_links(self, daemon_type):
-        # the attribute name to get these differs for schedulers and arbiters
+        # the attribute name to get these, differs for schedulers and arbiters
         return daemon_type + 's'
     
     
@@ -543,7 +662,7 @@ class Arbiter(Daemon):
                 if not os.path.exists(os.path.dirname(file_path)):
                     os.makedirs(os.path.dirname(file_path))
                 json.dump(daemons_to_write, open(file_path, 'w'))
-                logger.info('Current daemons are saved in file "%s" for checking for deleted daemons in next run: ' % (file_path))
+                logger.info('Current daemons are saved in file "%s" for checking for deleted daemons in next run: ' % file_path)
                 for (type_, nb_daemons) in _types_stats.items():
                     logger.info('   - %-15s : %d daemon(s)' % (type_, nb_daemons))
             except:
@@ -569,7 +688,7 @@ class Arbiter(Daemon):
             for _file in self.conf.bad_encoding_files:
                 logger.warning(u'[config] - %s' % _file)
         
-        # First we need to get arbiters and modules
+        # First we need to get arbiters and modules,
         # so we can ask them for objects
         self.conf.create_objects_for_type(raw_objects, u'arbiter')
         self.conf.create_objects_for_type(raw_objects, u'module')
@@ -599,18 +718,22 @@ class Arbiter(Daemon):
                          "with the value '%s'. "
                          "Thanks." % (self.arb_name if self.arb_name else "Arbiter", socket.gethostname()))
         
-        # Update the logger with our name
-        logger.set_name(self.me.get_name())
+        # Now we are sure who we are, we should update our name for log & process name
+        self.name = self.me.get_name()
+        logger.set_name(self.name)
         
         if self.is_master:
-            logger.info("I am the master Arbiter: %s" % self.me.get_name())
+            logger.info("I am the master Arbiter: %s" % self.name)
         else:
-            logger.info("I am a spare Arbiter: %s" % self.me.get_name())
+            logger.info("I am a spare Arbiter: %s" % self.name)
         
         logger.info("My own modules: " + ','.join([m.get_name() for m in self.me.modules]))
         
         # So I can update our name in the ini file
-        self.save_daemon_name_into_configuration_file(self.me.get_name())
+        self.save_daemon_name_into_configuration_file(self.name)
+        
+        # We will need a real display name early in this daemon because we will launch external modules very soon
+        self.compute_basic_display_name()
         
         self.modules_dir = getattr(self.conf, 'modules_dir', '')
         
@@ -671,7 +794,6 @@ class Arbiter(Daemon):
         self.conf.create_objects(raw_objects)
         self._finish_step('create_objects', before)
         
-        before = time.time()
         # Maybe conf is already invalid
         if not self.conf.conf_is_correct:
             self.conf.show_errors()
@@ -721,7 +843,7 @@ class Arbiter(Daemon):
             # Grok shards sent from workers
             self.conf.get_shards_from_sub_worker_manager()
             
-            # The shard managers is no more need
+            # The shard managers are no more needed
             self.conf.shutdown_sub_worker_manager()
             self._finish_step('compute shards into sub workers for each realm', before)
         
@@ -777,18 +899,19 @@ class Arbiter(Daemon):
         
         # The conf can be incorrect here if the cut into parts see errors like
         # a realm with hosts and not schedulers for it
+        flush_arbiter_message_buffer()
         if not self.conf.conf_is_correct:
             self.conf.show_errors()
             write_final_json()
             err = u'Configuration is incorrect, sorry, I bail out'
             logger.error(err)
-            sys.exit(err)
+            sys.exit(2)
         
         logger.info(u'Things look okay - No serious problems were detected during the pre-flight check')
         
         # Clean objects of temporary/unnecessary attributes for live work:
         self.conf.clean()
-        
+        flush_arbiter_message_buffer()
         # Exit if we are just here for config checking
         if self.verify_only:
             write_final_json()
@@ -879,10 +1002,20 @@ class Arbiter(Daemon):
     
     
     def _do_compute_shard_into_subprocess(self, realm):
+        # type: (Realm) -> None
         start = time.time()
         realm_name = realm.get_name()
         
-        # NOTE: the main daemon did disable the gc, but a fork() did already re-enable it
+        if os.getuid() == 0:
+            # Previous versions of Arbiter created root owned first monitoring time retention file.
+            #
+            for retention_file in [OLD_ARBITER_RETENTION_JSON, REALM_RETENTION_JSON % realm_name]:
+                if os.path.exists(retention_file):
+                    try:
+                        set_ownership(retention_file, user=getattr(self.conf, u'shinken_user', u'shinken'), group=getattr(self.conf, u'shinken_group', u'shinken'), is_link=os.path.islink(retention_file))
+                    except:
+                        raw_logger.get_sub_part(u'MONITORING START TIME COMPONENT').print_stack()
+        # NOTE: the main daemon disabled the gc, but a fork() already re-enabled it
         # Let this process ultra low level
         os.nice(20)
         set_process_name(u'shinken-arbiter - worker - compilation %s' % realm_name)
@@ -918,7 +1051,7 @@ class Arbiter(Daemon):
         before = time.time()
         count = self.conf.remove_exclusions()
         if count > 0:
-            # We removed excluded services, and so we must recompute the search lists
+            # We have removed excluded services, and so we must recompute the search lists
             self.conf.create_reversed_list()
         self._finish_step('remove check exclusions', before)
         
@@ -985,7 +1118,7 @@ class Arbiter(Daemon):
         # applying dependencies
         before = time.time()
         self.conf.apply_dependencies()
-        self._finish_step('declare depedencies', before)
+        self._finish_step('declare dependencies', before)
         
         # Explode global conf parameters into Classes
         before = time.time()
@@ -1046,9 +1179,10 @@ class Arbiter(Daemon):
             sys.exit(0)
         
         # Set & get monitoring start time, for this realm
-        # NOTE: if a host change realm, it will loose it's monitoring start time
+        # NOTE: if a host change realm, it will lose it's monitoring start time
         before = time.time()
-        self.conf.set_monitoring_start_time_realm_only(realm)
+        monitoring_start_time_component = MonitoringStartTimeComponent(logger, self.conf)
+        monitoring_start_time_component.set_monitoring_start_time_realm_only(realm)
         self._finish_step('set monitoring start time to new elements', before)
         
         end_write_arbiter_messages()
@@ -1084,9 +1218,6 @@ class Arbiter(Daemon):
                 for _file in self.conf.bad_encoding_files:
                     logger.warning('[config] - %s' % _file)
             
-            self.uri_arb = self.http_daemon.register(self.interface)
-            self.uri_stats = self.http_daemon.register(self.istats)
-            
             # ok we are now fully daemonized (if requested) now we can start our "external" modules (if any)
             self.modules_manager.start_external_instances()
             
@@ -1105,9 +1236,9 @@ class Arbiter(Daemon):
             # ends up here and must be handled.
             sys.exit(exp.code)
         except Exception as exp:
-            logger.critical("The daemon did have an unrecoverable error. It must exit.")
-            logger.critical("You can log a bug to your Shinken integrator with the error message:")
-            logger.critical("%s" % (traceback.format_exc()))
+            logger.critical(u'The daemon did have an unrecoverable error. It must exit.')
+            logger.critical(u'You can log a bug to your Shinken integrator with the error message:')
+            logger.print_stack(level=logging.CRITICAL)
             raise
     
     
@@ -1139,7 +1270,7 @@ class Arbiter(Daemon):
             logger_latest_monitoring_configuration.error(u'The NEW Monitoring Configuration received from the arbiter "%s" at "%s" is invalid, missing configuration_incarnation. skipping it.' % (arbiter_master_name, arbiter_master_uri))
             return
         arbiter_master_full_version = conf.get(u'arbiter_master_full_version', None)
-        if arbiter_master_full_version is None:  # not up to date master
+        if arbiter_master_full_version is None:  # not up-to-date master
             logger_latest_monitoring_configuration.error(u'The NEW Monitoring Configuration received from the arbiter master "%s" is too old and cannot be loaded: the Arbiter master is too old and must be updated.' % arbiter_master_name)
             return
         
@@ -1172,7 +1303,7 @@ class Arbiter(Daemon):
         self.have_configuration = True
     
     
-    # what ever the master is saying to us, we are switching to a idle way
+    # what ever the master is saying to us, we are switching to an idle way
     def arbiter_master__you_are_talking_to_me(self):  # IMPORTANT: read with an italian accent
         if self.must_run:
             self.must_run = False
@@ -1184,7 +1315,7 @@ class Arbiter(Daemon):
             logger_configuration.error(u'Received message not to run. I\'am the Master, ignore and continue to run.')
             return
         
-        # Else, I'm just a spare, so I listen to my master, if need, log it and go idle
+        # Else, I'm just a spare, so I listen to my master, if needed, log it and go idle
         self.arbiter_master__you_are_talking_to_me()
         logger_configuration.debug(u'Received message not to run from arbiter master')
         self.last_master_speak = time.time()
@@ -1208,7 +1339,7 @@ class Arbiter(Daemon):
     
     def load_new_configuration_incarnation_from_master(self, configuration_incarnation):
         self.configuration_incarnation = configuration_incarnation
-        logger_configuration.info('The NEW Monitoring Configuration is loaded from the last Arbiter MASTER configuration %s' % (configuration_incarnation))
+        logger_configuration.info('The NEW Monitoring Configuration is loaded from the last Arbiter MASTER configuration %s' % configuration_incarnation)
         # Also load the architecture name from the master
         old_architecture_name = self._architecture_name
         self._architecture_name = configuration_incarnation.get_architecture_name()
@@ -1220,7 +1351,7 @@ class Arbiter(Daemon):
         # If I am a spare, I wait for the master arbiter to send me true conf.
         if self.me.spare and not self._is_retention_load_already_try:
             self._is_retention_load_already_try = True  # Only load the retention once
-            # try to load the last receive conf, check the version, if match use it instead of non sync and probably false cfg files that are in this conf
+            # try to load the last receive conf, check the version, if match use it instead of non-sync and probably false cfg files that are in this conf
             self.conf = None
             self.dispatcher = None
             saved_conf = {}
@@ -1233,6 +1364,7 @@ class Arbiter(Daemon):
                 # we should have only one conf here
                 if len(saved_conf) == 1:
                     for version, pickled_full_conf in saved_conf.iteritems():
+                        version = self._format_daemon_full_version(version)
                         current_version = self.get_full_version()
                         if version != current_version:
                             # this conf was writen for another version of the arbiter the objects 'maybe' don't have the same representation
@@ -1246,7 +1378,7 @@ class Arbiter(Daemon):
                                 loaded_conf = None
                             if loaded_conf is not None:
                                 # Maybe the conf is too old, from a patch that fix arbiter->scheduler communication, so check this
-                                # and if the schedulers are not up to date, skip this conf object
+                                # and if the schedulers are not up-to-date, skip this conf object
                                 is_valid = loaded_conf.check_post_02_08_02_satellite_communication()
                                 if is_valid:
                                     self.conf = loaded_conf
@@ -1354,7 +1486,7 @@ class Arbiter(Daemon):
                 break
     
     
-    # Take all external commands, make packs and send them to  the schedulers
+    # Take all external commands, make packs and send them to the schedulers
     def push_external_commands_to_schedulers(self):
         # Now get all external commands and put them into the good schedulers
         for ext_cmd in self.external_commands:
@@ -1389,12 +1521,14 @@ class Arbiter(Daemon):
         if self.me:
             logger.set_name(self.me.get_name())
         
-        # We where waiting for check_interval to set arbiter trace
+        self.monitoring_start_time_component = MonitoringStartTimeComponent(logger, self.conf, compute_module_list=True)
+        
+        # We were waiting for check_interval to set arbiter trace
         self._generate_and_link_arbiter_trace()
         
         logger.set_human_format(on=self.conf.human_timestamp_log)
         logger.set_name(self.me.get_name())
-        # load the last run alive daemons to be able to ask them to do nothing once the conf will be send
+        # load the last run alive daemons to be able to ask them to do nothing once the conf will be sent
         self._load_last_run_alive_daemons()
         logger.info(u'Begin to dispatch configurations %s to satellites' % self.configuration_incarnation)
         self.dispatcher = Dispatcher(self.conf, self.me, self.trace, self.configuration_incarnation)
@@ -1411,7 +1545,7 @@ class Arbiter(Daemon):
         self.dispatcher.check_bad_dispatch()
         # REF: doc/shinken-conf-dispatching.png (3)
         self.dispatcher.dispatch()
-        # ask to the non anymore enabled daemons to stop working
+        # ask the no more enabled daemons to stop working
         self.dispatcher.disable_previous_run_daemons(self.last_run_alive_daemons, _PATH_ALIVE_DAEMONS)
         
         # Now we can get all initial broks for our satellites
@@ -1426,6 +1560,7 @@ class Arbiter(Daemon):
         
         logger.debug(u'Run baby, run... %s' % start_snap.get_diff())
         mainloop_watchdog = WatchDogThreadDumper(u'Main loop', wait_time=60 * 30, dump_interval=60 * 5, fatal_dead_lock_delay=60 * 30, multi_usage=True)
+        loop_logger = LoggerFactory.get_logger(u'ARBITER TIME')
         
         while self.must_run and not self.interrupted:
             with mainloop_watchdog:
@@ -1434,7 +1569,7 @@ class Arbiter(Daemon):
                 loop_start = time.time()
                 self._increase_loop_number()
                 loop_number = self._get_loop_number()
-                logger.info('[ARBITER TIME  ] [ === Loop start === ] [ Loop number=%-5d ] ===-===-===-===-===-===-===-===-===-===-===-===-===' % loop_number)
+                loop_logger.info(u'[ === Loop start === ] [ Loop number=%-5d ] ===-===-===-===-===-===-===-===-===-===-===-===-===' % loop_number)
                 # Try to see if one of my module is dead, and
                 # try to restart previously dead modules :)
                 self.check_and_del_zombie_modules()
@@ -1466,6 +1601,12 @@ class Arbiter(Daemon):
                 
                 self.get_external_commands_from_satellites()
                 
+                # First get message from satellites : maybe the response is received and don't need to ask sanitize
+                self.get_messages_from_satellites()
+                
+                self.launch_sanitize()
+                self.send_messages_to_satellites()
+                
                 if self.nb_broks_send != 0:
                     logger.debug("Nb Broks send: %d" % self.nb_broks_send)
                 self.nb_broks_send = 0
@@ -1479,8 +1620,8 @@ class Arbiter(Daemon):
                 logger_perf.info('Time to do send broks to brokers and push shinken internal commands (like recheck, set acknowledge, etc) to schedulers [ %.3f ]s' % (time.time() - other_taks_start))
                 
                 diff_time = time.time() - loop_start
-                logger.info('[ARBITER TIME  ] [ === Loop stop  === ] [ Loop number=%-5d ] [PERF] [ %.3f ]s' % (loop_number, diff_time))
-                logger.debug('[ARBITER TIME  ] [ === Loop stop  === ] [ Loop number=%-5d ] [PERF] %s' % (loop_number, loop_snap.get_diff()))
+                loop_logger.info('[ === Loop stop  === ] [ Loop number=%-5d ] [PERF] [ %.3f ]s' % (loop_number, diff_time))
+                loop_logger.debug('[ === Loop stop  === ] [ Loop number=%-5d ] [PERF] %s' % (loop_number, loop_snap.get_diff()))
                 
                 # Protect it against time shifting from system
                 sleep_time = 1 - diff_time
@@ -1510,3 +1651,9 @@ class Arbiter(Daemon):
     # Get back our data from a retention module
     def restore_retention_data(self, data):
         return
+    
+    
+    def launch_sanitize(self):
+        messages = self.monitoring_start_time_component.get_inter_daemon_message_to_send(self.name)
+        for message in messages:
+            self.send_message_to_satellites(message)
