@@ -733,11 +733,7 @@ class Executor(BaseSatellite):
     
     # Do this satellite (poller or reactionner) post 'daemonize' init: we must register our interfaces for 4 possible callers: arbiter, schedulers, brokers and stat.
     def _do_post_daemon_init(self):
-        # Register all interface
-        self._register_http_interfaces()
-        
         self._workers[u'fork'] = {}  # type: Dict[int, Worker]
-        
         # For multiprocess things, we should not have socket timeouts.
         socket.setdefaulttimeout(None)
     
