@@ -266,7 +266,7 @@ class ExternalCommandManager:
         'PROCESS_SERVICE_CHECK_RESULT': 'Check result',
         'ACKNOWLEDGE_HOST_PROBLEM'    : 'Host acknowledge',
         'ACKNOWLEDGE_SVC_PROBLEM'     : 'Check acknowledge',
-        'REMOVE_HOST_ACKNOWLEDGEMENT' : 'Host acknowledge deleteion',
+        'REMOVE_HOST_ACKNOWLEDGEMENT' : 'Host acknowledge deletion',
         'REMOVE_SVC_ACKNOWLEDGEMENT'  : 'Check acknowledge deletion',
         'SCHEDULE_FORCED_HOST_CHECK'  : 'Schedule immediate host',
         'SCHEDULE_FORCED_SVC_CHECK'   : 'Schedule immediate check',
