@@ -133,7 +133,7 @@ class CherryPyBackend(object):
                             to_print.append("%s" % line)
                 elif isinstance(error, bottle.HTTPError):
                     # app.abord make a HTTPError without traceback see SEF-6067
-                    to_print = ['HTTPError : code[%s] message:[%s]' % (error.status, error.output)]
+                    to_print = ['HTTPError : code[%s] message:[%s]' % (error.status, error.body)]
                 else:
                     to_print = [str(error)]
                 return "<br/>".join(to_print)
