@@ -23,14 +23,13 @@
 # along with Shinken.  If not, see <http://www.gnu.org/licenses/>.
 
 import codecs
+import itertools
 import os
 import re
 from ctypes import c_int
 from logging.handlers import TimedRotatingFileHandler
 from multiprocessing import RLock, Value
 
-import itertools
-
 import six
 
 # Typing
@@ -477,8 +476,8 @@ class Log(logging.Logger):
         from brok import Brok
         if self._my_daemon is None:
             return
-        msg = '[%d] %7s: [%s] %s\n' % (time.time(), level.upper(), logger.name, message)
-        brok = Brok('log_monitoring', {'log': msg})
+        msg = u'[%d] %7s: [%s] %s\n' % (time.time(), level.upper(), logger.name, message)
+        brok = Brok(u'log_monitoring', {u'log': msg})
         self._my_daemon.add_Brok(brok)
         # Also log into the scheduler log as classic log
         self.info(message)
@@ -946,7 +945,7 @@ loggers = {DEFAULT_LOG: PartLogger(DEFAULT_LOG)}
 class LoggerFactory(object):
     @classmethod
     def get_logger(cls, name=DEFAULT_LOG, part_name_size=LOG_CHAPTER_SIZE):
-        # type: (unicode, int) -> PartLogger
+        # type: (unicode, Optional[int]) -> PartLogger
         if six.PY2 and not isinstance(name, basestring):
             name = unicode(name)
         
