@@ -87,10 +87,23 @@ class MonitoringItemManager(object):
         return self.rg.services.find_srv_by_name_and_hostname(hname, sdesc)
     
     
+    def get_service_case_insensitive(self, host_name, check_name):
+        if isinstance(host_name, str):
+            host_name = host_name.decode('utf8', 'ignore')
+        if isinstance(check_name, str):
+            check_name = check_name.decode('utf8', 'ignore')
+        return self.rg.services.find_service_by_name_case_insensitive(host_name, check_name)
+    
+    
     def get_all_hosts_and_services(self):
         return self.rg.all_hosts_and_services
     
     
+    def get_count_items(self):
+        # type: () -> Dict[unicode, int]
+        return self.rg.item_counter
+    
+    
     def get_contact(self, name, by_id=False):
         if isinstance(name, str):
             name = name.decode('utf8', 'ignore')
