@@ -224,9 +224,10 @@ class Regenerator(object):
         self._have_received_initial_broks = False
         self.detail_timer = {}
         self.item_counter = {
+            u'all'             : 0,
             u'hosts'           : 0,
             u'clusters'        : 0,
-            u'services'        : 0,
+            u'checks'          : 0,
             u'contacts'        : 0,
             u'notificationways': 0,
             u'hostgroups'      : 0,
@@ -497,12 +498,6 @@ class Regenerator(object):
         t5 = time.time()
         logger_perf.info(u'Merging incoming service groups with already existing ones ---------------- : %.2f' % (t5 - t4))
         
-        # Optimize service lookup before clean them
-        self.services.optimize_service_search(self.hosts, build_service_on_host_index=True)
-        
-        t51 = time.time()
-        logger_perf.info(u'Indexing check on host ---------------------------------------------------- : %.2f' % (t51 - t5))
-        
         sum1 = 0.0
         sum2 = 0.0
         sum3 = 0.0
@@ -563,8 +558,14 @@ class Regenerator(object):
             # logger_perf.debug(u'Creation the service : %s' % service.get_full_name())
         
         t6 = time.time()
-        logger_perf.info(u'Linking services => host / servicegroups / command / timeperiod / contact - : %.2f' % (t6 - t51))
+        logger_perf.info(u'Linking services => host / servicegroups / command / timeperiod / contact - : %.2f' % (t6 - t5))
         logger_perf.debug(u'Sub times: 1:%.2f  2:%.2f  3:%.2f  4:%.2f' % (sum1, sum2, sum3, sum4))
+
+        # Optimize service lookup before clean them
+        self.services.optimize_service_search(self.hosts, build_service_on_host_index=True)
+
+        t61 = time.time()
+        logger_perf.info(u'Indexing check on host ---------------------------------------------------- : %.2f' % (t61 - t6))
         
         # Link services into service groups
         # First clean members
@@ -698,6 +699,7 @@ class Regenerator(object):
         
         nb_clusters = len([h for h in self.hosts if h.got_business_rule])
         self.item_counter = {
+            u'all'             : len(self.hosts) + len(self.services),
             u'hosts'           : len(self.hosts) - nb_clusters,
             u'clusters'        : nb_clusters,
             u'checks'          : len(self.services),
