@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
-# Copyright (C) 2009-2012:
+#
+# Copyright (C) 2009-2022:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -25,6 +25,7 @@
 import codecs
 import os
 import shutil
+import string
 import time
 
 from shinken.misc.type_hint import TYPE_CHECKING
@@ -48,6 +49,13 @@ class ShinkenFileNotFoundError(ShinkenFileError):
     pass
 
 
+def clean_file_name(path):
+    # type: (unicode) -> unicode
+    valid_chars = u'-_./\\ %s%s' % (string.ascii_letters, string.digits)
+    path_clean = u''.join(ch if ch in valid_chars else str(ord(ch)) for ch in path)
+    return path_clean
+
+
 def make_file_hidden(file_path):
     # type: (unicode) -> unicode
     file_dir = os.path.dirname(file_path)
@@ -125,7 +133,7 @@ def check_file_or_directory_access(target_path, logger=None, check_read=True, ch
     # type: (unicode, PartLogger, bool, bool, bool) -> None
     if check_exists and not os.path.exists(target_path):
         if logger:
-            logger.debug(u'The path does not exist [ %s ] was it move ?' % target_path)
+            logger.debug(u'The path does not exist [ %s ] was it moved ?' % target_path)
         raise ShinkenFileNotFoundError(u'The path does not exist : %s' % target_path)
     
     has_access_issue = False
