@@ -22,14 +22,13 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Shinken.  If not, see <http://www.gnu.org/licenses/>.
 
+import imp
 import inspect
 import json
 import os
-from threading import RLock, Thread
-
-import imp
 import sys
 import time
+from threading import RLock, Thread
 
 from shinken.log import LoggerFactory
 from shinken.misc.type_hint import TYPE_CHECKING
@@ -435,7 +434,7 @@ class ModulesManager(object):
     
     
     def get_module_code_with_module_type(self, module_type):
-        # type: (str) -> Optional[ModuleCode]
+        # type: (unicode) -> Optional[ModuleCode]
         module_type = uniform_module_type(module_type)
         
         for py_module in self.imported_modules:
@@ -508,7 +507,6 @@ class ModulesManager(object):
     def set_to_restart(self, inst, reason='', is_an_error=True):
         # type: (BaseModule, unicode, bool) -> None
         already_set_to_restart = inst.get_name() in self.to_restart
-        self.to_restart[inst.get_name()] = inst
         try:
             inst.stop_all()
         except:
@@ -516,10 +514,11 @@ class ModulesManager(object):
             if inst.is_external or inst.is_worker_based:
                 inst.clear_queues()
                 inst.kill_manager()
-        if inst.get_internal_state() == ModuleState.FATAL:
+        if inst.get_internal_state() == ModuleState.FATAL and is_an_error:
             inst.fatal_error_has_been_managed = True
             inst.stop_all()
             return
+        self.to_restart[inst.get_name()] = inst
         if is_an_error and (reason or not already_set_to_restart):
             self.__register_module_restart(inst.get_name(), reason)
     
@@ -652,7 +651,7 @@ class ModulesManager(object):
             self.set_to_restart(inst, is_an_error=False)
             return False
         if did_init == INSTANCE_INIT_STATE.INIT_FAILED:
-            _logger.error(u'The worker base module failed to init. The module will be restarted in the future.')
+            _logger.error(u'The worker base module failed to init.')
             self.set_to_restart(inst)
             return False
         
@@ -821,6 +820,7 @@ class ModulesManager(object):
     
     
     def get_all_alive_instances(self):
+        # type: () -> List[BaseModule]
         with self.instances_lock:
             return self._get_instances_with_condition(lambda inst: inst not in self.to_restart.values() and inst.get_internal_state() != ModuleState.FATAL)
     
