@@ -51,55 +51,57 @@ class Contact(InheritableItem):
     properties = InheritableItem.properties.copy()
     properties.update({
         ############################# Simple properties, can be set into a C structure
-        'host_notifications_enabled'   : BoolProp(default='1', fill_brok=['full_status']),
-        'service_notifications_enabled': BoolProp(default='1', fill_brok=['full_status']),
-        'min_business_impact'          : IntegerProp(default='0', fill_brok=['full_status']),
-        'can_submit_commands'          : BoolProp(default='1', fill_brok=['full_status']),
-        'is_admin'                     : BoolProp(default='0', fill_brok=['full_status']),
+        'host_notifications_enabled'             : BoolProp(default='1', fill_brok=['full_status']),
+        'service_notifications_enabled'          : BoolProp(default='1', fill_brok=['full_status']),
+        'min_business_impact'                    : IntegerProp(default='0', fill_brok=['full_status']),
+        'can_submit_commands'                    : BoolProp(default='1', fill_brok=['full_status']),
+        'is_admin'                               : BoolProp(default='0', fill_brok=['full_status']),
         
-        'expert'                       : BoolProp(default='0', fill_brok=['full_status']),
+        'expert'                                 : BoolProp(default='0', fill_brok=['full_status']),
         
-        'acl_show_history_range'       : BoolProp(default='1', fill_brok=['full_status']),
-        'acl_show_sla_range'           : BoolProp(default='1', fill_brok=['full_status']),
-        'acl_make_downtime'            : BoolProp(default='1', fill_brok=['full_status']),
-        'acl_make_acknowledge'         : BoolProp(default='1', fill_brok=['full_status']),
-        'acl_force_result_check'       : BoolProp(default='1', fill_brok=['full_status']),
-        'acl_force_retry_check'        : BoolProp(default='1', fill_brok=['full_status']),
-        'default_submit_to_staging'    : BoolProp(default='1'),  # for synchronizer by pass working area
-        'acl_try_check_on_poller'      : BoolProp(default='1'),  # for synchronizer right
-        'acl_try_check_on_synchronizer': BoolProp(default='1'),  # for synchronizer right
-        'acl_show_external_url'        : BoolProp(default='1', fill_brok=['full_status']),  # for synchronizer right
+        'acl_show_history_range'                 : BoolProp(default='1', fill_brok=['full_status']),
+        'acl_show_sla_range'                     : BoolProp(default='1', fill_brok=['full_status']),
+        'acl_make_downtime'                      : BoolProp(default='1', fill_brok=['full_status']),
+        'acl_make_acknowledge'                   : BoolProp(default='1', fill_brok=['full_status']),
+        'acl_force_result_check'                 : BoolProp(default='1', fill_brok=['full_status']),
+        'acl_force_retry_check'                  : BoolProp(default='1', fill_brok=['full_status']),
+        'default_submit_to_staging'              : BoolProp(default='1'),  # for synchronizer by pass working area
+        'acl_try_check_on_poller'                : BoolProp(default='1'),  # for synchronizer right
+        'acl_try_check_on_synchronizer'          : BoolProp(default='1'),  # for synchronizer right
+        'acl_show_external_url'                  : BoolProp(default='1', fill_brok=['full_status']),  # for synchronizer right
         
         ########################### Configuration Structure, like links to others elements
-        'contact_name'                 : StringProp(fill_brok=['full_status']),
-        'alias'                        : StringProp(default='none', fill_brok=['full_status']),
-        'contactgroups'                : LinkToOthersObjectsProp(default='', fill_brok=['full_status'], merging='join', handle_additive_inheritance=True),
-        'host_notification_period'     : LinkToAnotherObjectProp(default='24x7', fill_brok=['full_status']),
-        'service_notification_period'  : LinkToAnotherObjectProp(default='24x7', fill_brok=['full_status']),
+        'contact_name'                           : StringProp(fill_brok=['full_status']),
+        'alias'                                  : StringProp(default='none', fill_brok=['full_status']),
+        'contactgroups'                          : LinkToOthersObjectsProp(default='', fill_brok=['full_status'], merging='join', handle_additive_inheritance=True),
+        'host_notification_period'               : LinkToAnotherObjectProp(default='24x7', fill_brok=['full_status']),
+        'service_notification_period'            : LinkToAnotherObjectProp(default='24x7', fill_brok=['full_status']),
         
         # Theses one can be size bounded
-        'host_notification_options'    : StringProp(default='d,u,r,f', fill_brok=['full_status']),
-        'service_notification_options' : StringProp(default='w,u,c,r,f,s', fill_brok=['full_status']),
-        'host_notification_commands'   : StringProp(fill_brok=['full_status']),
-        'service_notification_commands': StringProp(fill_brok=['full_status']),
+        'host_notification_options'              : StringProp(default='d,u,r,f', fill_brok=['full_status']),
+        'service_notification_options'           : StringProp(default='w,u,c,r,f,s', fill_brok=['full_status']),
+        'host_notification_commands'             : StringProp(fill_brok=['full_status']),
+        'service_notification_commands'          : StringProp(fill_brok=['full_status']),
         
-        'email'                        : StringProp(default='none', fill_brok=['full_status']),
-        'pager'                        : StringProp(default='none', fill_brok=['full_status']),
-        'address1'                     : StringProp(default='none', fill_brok=['full_status']),
-        'address2'                     : StringProp(default='none', fill_brok=['full_status']),
-        'address3'                     : StringProp(default='none', fill_brok=['full_status']),
-        'address4'                     : StringProp(default='none', fill_brok=['full_status']),
-        'address5'                     : StringProp(default='none', fill_brok=['full_status']),
-        'address6'                     : StringProp(default='none', fill_brok=['full_status']),
+        'email'                                  : StringProp(default='none', fill_brok=['full_status']),
+        'pager'                                  : StringProp(default='none', fill_brok=['full_status']),
+        'address1'                               : StringProp(default='none', fill_brok=['full_status']),
+        'address2'                               : StringProp(default='none', fill_brok=['full_status']),
+        'address3'                               : StringProp(default='none', fill_brok=['full_status']),
+        'address4'                               : StringProp(default='none', fill_brok=['full_status']),
+        'address5'                               : StringProp(default='none', fill_brok=['full_status']),
+        'address6'                               : StringProp(default='none', fill_brok=['full_status']),
         
-        'notificationways'             : LinkToOthersObjectsProp(default='', merging='join', fill_brok=['full_status'], handle_additive_inheritance=True),
-        'password'                     : StringProp(default='', fill_brok=['full_status']),
-        'display_name'                 : StringProp(default=''),
+        'notificationways'                       : LinkToOthersObjectsProp(default='', merging='join', fill_brok=['full_status'], handle_additive_inheritance=True),
+        'password'                               : StringProp(default='', fill_brok=['full_status']),
+        'display_name'                           : StringProp(default=''),
         
-        'acl_in_tab_history'           : StringProp(default='history_sla', fill_brok=['full_status']),
-        'acl_share_private'            : AclShareProp(default='all', fill_brok=['full_status']),
-        'acl_share_group'              : AclShareProp(default='all', fill_brok=['full_status']),
-        'acl_share_everybody'          : AclShareProp(default='all', fill_brok=['full_status']),
+        'acl_in_tab_history'                     : StringProp(default='history_sla', fill_brok=['full_status']),
+        'acl_share_private'                      : AclShareProp(default='all', fill_brok=['full_status']),
+        'acl_share_group'                        : AclShareProp(default='all', fill_brok=['full_status']),
+        'acl_share_everybody'                    : AclShareProp(default='all', fill_brok=['full_status']),
+        
+        'authentication_cookie_validity_duration': IntegerProp(default='5256000', fill_brok=['full_status'])  # 5256000 -> 10 year in min
     })
     
     running_properties = InheritableItem.running_properties.copy()
@@ -142,6 +144,10 @@ class Contact(InheritableItem):
         'for_all_users': BoolProp(default='1'),
     })
     
+    if TYPE_CHECKING:
+        authentication_cookie_validity_duration = 0
+        is_admin = True
+    
     
     def get_name(self):
         return getattr(self, 'contact_name', getattr(self, 'name', 'UnnamedContact'))
