@@ -118,7 +118,7 @@ class Host(SchedulingItem):
         # service_excludes = None   # type: Optional[??]
         # service_excludes_by_id = None   # type: Optional[??]
         service_overrides = u''
-
+        
         retain_status_information = True
         retain_nonstatus_information = True
         stalking_options = u''
@@ -410,7 +410,7 @@ class Host(SchedulingItem):
         
         for _warning in self.configuration_warnings:
             log_configuration_warning(self, _warning)
-
+        
         if self.configuration_errors:
             state = False
             for _error in self.configuration_errors:
@@ -493,6 +493,22 @@ class Host(SchedulingItem):
         return None
     
     
+    def find_service_by_name_case_insensitive(self, service_description):
+        # type: (unicode) -> Optional[Service]
+        
+        service_description = service_description.lower()
+        # service on host can be indexed (it will in broker and scheduler)
+        service_index = getattr(self, 'service_index', {})
+        if service_index:
+            service_index_by_name_case_insensitive = getattr(self, 'service_index_by_name_case_insensitive', {})
+            service_id = service_index_by_name_case_insensitive.get(service_description, None)
+            if service_id is not None:
+                return service_index.get(service_id, None)
+        else:
+            return next((service for service in self.services if getattr(service, 'service_description', '__UNNAMED_SERVICE__').lower() == service_description), None)
+        return None
+    
+    
     # Search in my service if I've got the service
     def find_service_by_uuid(self, uuid):
         # type: (unicode) -> Optional[Service]
@@ -500,8 +516,8 @@ class Host(SchedulingItem):
         # service on host can be indexed (it will in broker and scheduler)
         service_index = getattr(self, 'service_index', {})
         if service_index:
-            service_index_by_name = getattr(self, 'service_index_by_uuid', {})
-            service_id = service_index_by_name.get(uuid, None)
+            service_index_by_uuid = getattr(self, 'service_index_by_uuid', {})
+            service_id = service_index_by_uuid.get(uuid, None)
             if service_id is not None:
                 return service_index.get(service_id, None)
         else:
@@ -1374,6 +1390,7 @@ class Host(SchedulingItem):
     def build_service_index(self):
         service_index = {}
         service_index_by_name = {}
+        service_index_by_name_case_insensitive = {}
         service_index_by_uuid = {}
         for service in self.services:
             service_id = service.id
@@ -1381,9 +1398,11 @@ class Host(SchedulingItem):
             service_uuid = getattr(service, 'uuid', '__NO_UUID__')
             service_index[service_id] = service
             service_index_by_name[service_name] = service_id
+            service_index_by_name_case_insensitive[service_name.lower()] = service_id
             service_index_by_uuid[service_uuid] = service_id
         setattr(self, 'service_index', service_index)
         setattr(self, 'service_index_by_name', service_index_by_name)
+        setattr(self, 'service_index_by_name_case_insensitive', service_index_by_name_case_insensitive)
         setattr(self, 'service_index_by_uuid', service_index_by_uuid)
 
 
