@@ -82,6 +82,16 @@ class PERIOD_PROPERTIES(object):
 
 
 class Item(object):
+    if TYPE_CHECKING:
+        my_type = u''
+        imported_from = u''
+        definition_order = 100
+        uuid = u''
+        configuration_warnings = []
+        configuration_errors = []
+        hash = u''
+        tags = []
+    
     properties = {
         'imported_from'   : StringProp(default='unknown'),
         'definition_order': IntegerProp(default='100'),
@@ -158,7 +168,8 @@ class Item(object):
     
     # When values to set on attributes are unique (single element list),
     # return the value directly rather than setting list element.
-    def _compact_unique_attr_value(self, val):
+    @staticmethod
+    def _compact_unique_attr_value(val):
         if not isinstance(val, list):
             return val
         # ok not a simple value
@@ -883,8 +894,7 @@ class Items(object):
         # type: () -> bool
         # we are ok at the beginning. Hope we are still ok at the end...
         config_is_correct = True
-        # Some class do not have twins, because they do not have names
-        # like servicedependencies
+        # Some class do not have twins, because they do not have names like servicedependencies
         twins = getattr(self, 'twins', None)
         if twins is not None:
             # Ok, look at no twins (it's bad!)
@@ -977,7 +987,7 @@ class Items(object):
                             c = contacts.find_by_name(c_name)
                             if c is not None:
                                 new_contacts.append(c)
-                            # DEAD CODE WARNING: we did used to show a warning, but it's just too much for logs/output
+                            # DEAD CODE WARNING: we used to show a warning, but it's just too much for logs/output
                             #       so do nothing, it's up to the configuration daemon to show it
                             # else:
                             #    err = "the contact '%s' defined for '%s' is disabled or does not exist" % (c_name, i.get_name())
@@ -1017,7 +1027,6 @@ class Items(object):
                     else:
                         err = u'the result modulation \'%s\' defined on the %s \'%s\' is disabled or does not exist' % (rm_name, i.__class__.my_type, i.get_name())
                         i.configuration_errors.append(err)
-                        continue
                 i.resultmodulations = tuple(new_resultmodulations)
     
     
