@@ -26,11 +26,10 @@
 If you look at the scheduling part, look at the scheduling item class"""
 import hashlib
 import re
+import time
 from collections import deque
 from collections import namedtuple
 
-import time
-
 from shinken.autoslots import AutoSlots
 from shinken.eventhandler import EventHandler
 from shinken.log import logger, naglog_result
@@ -946,10 +945,7 @@ class Service(SchedulingItem):
     # Raise a log entry when a downtime begins
     # SERVICE DOWNTIME ALERT: test_host_0;test_ok_0;STARTED; Service has entered a period of scheduled downtime
     def raise_enter_downtime_log_entry(self):
-        naglog_result('critical', "SERVICE DOWNTIME ALERT: %s;%s;STARTED; "
-                                  "Service has entered a period of scheduled "
-                                  "downtime"
-                      % (self.host.get_name(), self.get_name()))
+        naglog_result(u'critical', u'SERVICE DOWNTIME ALERT: %s;%s;STARTED; Service has entered a period of scheduled downtime' % (self.host.get_name(), self.get_name()))
     
     
     # Raise a log entry when a downtime has finished
@@ -1361,7 +1357,17 @@ class Services(InheritableItems):
         if hasattr(self, 'hosts'):
             h = self.hosts.find_by_uuid(host_uuid)
             if h is not None:
-                return h.find_service_by_uuid(check_uuid)
+                check = h.find_service_by_uuid(check_uuid)
+                return check
+        return None
+    
+    
+    def find_service_by_name_case_insensitive(self, host_name, check_name):
+        if hasattr(self, 'hosts'):
+            h = self.hosts.get_host_case_insensitive(host_name)
+            if h is None:
+                return None
+            return h.find_service_by_name_case_insensitive(check_name)
         return None
     
     
