@@ -103,6 +103,9 @@ if TYPE_CHECKING:
     from shinken.misc.type_hint import List, Dict
 
 TIMEPERIOD_VERSION = 1
+TIMEPERIOD_24X7 = set([u'monday 00:00-24:00', u'tuesday 00:00-24:00', u'friday 00:00-24:00', u'wednesday 00:00-24:00', u'thursday 00:00-24:00', u'sunday 00:00-24:00', u'saturday 00:00-24:00'])
+THIRTY_DAY_AS_SECONDS = 3600 * 24 * 30
+ONE_YEAR_AS_SECONDS = 3600 * 24 * 366 + 1
 
 
 class Timeperiod(Item):
@@ -124,7 +127,9 @@ class Timeperiod(Item):
     running_properties = Item.running_properties.copy()
     
     
-    def __init__(self, params={}, skip_useless_in_configuration=False):
+    def __init__(self, params=None, skip_useless_in_configuration=False):
+        if params is None:
+            params = {}
         self.id = Timeperiod.id
         Timeperiod.id = Timeperiod.id + 1
         self.unresolved = []
@@ -158,9 +163,10 @@ class Timeperiod(Item):
         
         self.configuration_errors = []
         self.configuration_warnings = []
-        # By default the tp is None so we know we just start
+        # By default, the tp is None, so we know we just start
         self.is_active = None
         self.tags = list()
+        self.time_is_always_valid = False
     
     
     def get_name(self):
@@ -192,26 +198,29 @@ class Timeperiod(Item):
         return r
     
     
-    def is_time_valid(self, t):
-        t = int(t)  # be sure to have an int, because all daterange code is done for compare int and not float
+    def is_time_valid(self, time_to_check):
+        time_to_check = int(time_to_check)  # be sure to have an int, because all daterange code is done for compare int and not float
         # note: float can be just a few ms AFTER the last second, as this last one is a INT
         
-        res_from_cache = self.find_is_time_valid_from_cache(t)
+        if self.time_is_always_valid:
+            return True
+        
+        res_from_cache = self.find_is_time_valid_from_cache(time_to_check)
         if res_from_cache is not None:
             return res_from_cache
         
         if self.has('exclude'):
             for tp in self.exclude:
-                if tp.is_time_valid(t):
-                    self._is_time_valid_cache[t] = False
+                if tp.is_time_valid(time_to_check):
+                    self._is_time_valid_cache[time_to_check] = False
                     return False
         
         for dr in self.dateranges:
-            if dr.is_time_valid(t):
-                self._is_time_valid_cache[t] = True
+            if dr.is_time_valid(time_to_check):
+                self._is_time_valid_cache[time_to_check] = True
                 return True
         
-        self._is_time_valid_cache[t] = False
+        self._is_time_valid_cache[time_to_check] = False
         return False
     
     
@@ -290,131 +299,122 @@ class Timeperiod(Item):
                 del cache[time_in_cache]
     
     
-    def get_next_valid_time_from_t(self, t, max_t=3600 * 24 * 366 + 1):
+    def get_next_valid_time_from_t(self, t, max_t=ONE_YEAR_AS_SECONDS):
         # first find from cache
         t = int(t)
         original_t = t
         
         # logger.debug("[%s] Check valid time for %s" % ( self.get_name(), time.asctime(time.localtime(t)))
+        if self.time_is_always_valid:
+            return t
         
         res_from_cache = self.find_next_valid_time_from_cache(t)
         if res_from_cache is not None:
             return res_from_cache
         
-        still_loop = True
+        local_min = None
         
-        # Loop for all minutes...
-        while still_loop:
+        first_valid_time_in_daterange = []
+        
+        for dr in self.dateranges:
+            first_valid_time_in_daterange.append(dr.get_next_valid_time_from_t(t))
+        
+        sorted_first_valid_time_in_daterange = sorted([d for d in first_valid_time_in_daterange if d is not None])
+        if sorted_first_valid_time_in_daterange:
+            local_min = sorted_first_valid_time_in_daterange[0]
+            if self.exclude:
+                for exclude_timeperiod in self.exclude:
+                    if exclude_timeperiod.is_time_valid(local_min):
+                        max_lookup_time = max_t - (local_min - t)
+                        if max_lookup_time <= 0:
+                            local_min = None
+                        exclude_end = exclude_timeperiod.get_next_invalid_time_from_t(local_min, max_period_to_search=max_lookup_time)
+                        if exclude_end:
+                            max_lookup_time = max_t - (exclude_end - t)
+                            if max_lookup_time <= 0:
+                                local_min = None
+                            else:
+                                local_min = self.get_next_valid_time_from_t(exclude_end, max_t=max_lookup_time)
+                        else:
+                            local_min = None
+        
+        if local_min and local_min > (original_t + max_t):
+            # No loop more than one year
             local_min = None
-            
-            # Ok, not in cache...
-            dr_mins = []
-            s_dr_mins = []
-            
-            for dr in self.dateranges:
-                dr_mins.append(dr.get_next_valid_time_from_t(t))
-            
-            s_dr_mins = sorted([d for d in dr_mins if d is not None])
-            
-            for t1 in s_dr_mins:
-                if not self.exclude and still_loop is True:
-                    # No Exclude so we are good
-                    local_min = t1
-                    still_loop = False
-                else:
-                    for tp in self.exclude:
-                        if not tp.is_time_valid(t1) and still_loop is True:
-                            # OK we found a date that is not valid in any exclude timeperiod
-                            local_min = t1
-                            still_loop = False
-            
-            if local_min is None:
-                # print "Looking for next valid date"
-                exc_mins = []
-                if s_dr_mins != []:
-                    for tp in self.exclude:
-                        exc_mins.append(tp.get_next_invalid_time_from_t(s_dr_mins[0]))
-                
-                s_exc_mins = sorted([d for d in exc_mins if d is not None])
-                
-                if s_exc_mins != []:
-                    local_min = s_exc_mins[0]
-            
-            if local_min is None:
-                still_loop = False
-            else:
-                t = local_min
-                # No loop more than one year
-                if t > original_t + max_t:
-                    still_loop = False
-                    local_min = None
         
-        # Ok, we update the cache...
-        self.cache[original_t] = local_min
+        # We update the cache if the max_period_to_search is far in future because if the max_period_to_search if too small we will not find the real next invalid
+        if max_t >= ONE_YEAR_AS_SECONDS:
+            self.cache[original_t] = local_min
         return local_min
     
     
-    def get_next_invalid_time_from_t(self, t, max_t=3600 * 24 * 366 + 1):
-        t = int(t)
-        original_t = t
+    def get_next_invalid_time_from_t(self, start_time, max_period_to_search=ONE_YEAR_AS_SECONDS):
+        start_time = int(start_time)
+        original_start_time = start_time
         still_loop = True
         
+        if self.time_is_always_valid:
+            return start_time + max_period_to_search
+        
         # First try to find in cache
-        res_from_cache = self.find_next_invalid_time_from_cache(t)
+        res_from_cache = self.find_next_invalid_time_from_cache(start_time)
         if res_from_cache is not None:
             return res_from_cache
         
-        # Then look, maybe t is already invalid
-        if not self.is_time_valid(t):
-            return t
+        # Then look, maybe start_time is already invalid
+        if not self.is_time_valid(start_time):
+            return start_time
+        
+        local_min = start_time
+        time_padding = 60
         
-        local_min = t
-        res = None
         # Loop for all minutes...
         while still_loop:
-            dr_mins = []
-            # But maybe we can find a better solution with next invalid of standard dateranges
-            for dr in self.dateranges:
-                m = dr.get_next_invalid_time_from_t(local_min)
-                if m is not None:
-                    dr_mins.append(m)
+            by_daterange_next_invalid_times = []
             
-            if dr_mins != []:
-                local_min = min(dr_mins)
+            # But maybe we can find a better solution with next invalid of standard date ranges
+            for daterange in self.dateranges:
+                by_daterange_next_invalid_time = daterange.get_next_invalid_time_from_t(local_min)
+                if by_daterange_next_invalid_time is not None:
+                    by_daterange_next_invalid_times.append(by_daterange_next_invalid_time)
             
-            # We do not loop unless the local_min is not valid
+            if by_daterange_next_invalid_times:
+                local_min = min(by_daterange_next_invalid_times)
+            
+            # Now check if local_min is valid
             if not self.is_time_valid(local_min):
+                # We can stop we found the next invalid because self is invalid
                 still_loop = False
-            else:  # continue until we reach too far..., in one minute
-                # After one month, go quicker...
-                if local_min > original_t + 3600 * 24 * 30:
-                    local_min += 3600
-                else:  # else search for 1min precision
-                    local_min += 60
-                # after one year, stop.
-                if local_min > original_t + max_t:  # 60*24*366 + 1:
+                break
+            
+            # Now check exclude. The next valid from exclude will be our next invalid
+            for exclude_tp in self.exclude:
+                if exclude_tp.is_time_valid(local_min):
+                    # local_min is in valid period of an excluded, so we can stop
                     still_loop = False
+                    
+                    # We go back in time to found the start of exclude period
+                    next_invalid_from_tp = exclude_tp.get_next_valid_time_from_t(local_min - time_padding, time_padding + 1)
+                    if next_invalid_from_tp is not None and next_invalid_from_tp < local_min:
+                        local_min = next_invalid_from_tp
+                        if local_min < original_start_time:
+                            local_min = original_start_time
+                            
+                            # After one month, go quicker...
+            if local_min > original_start_time + THIRTY_DAY_AS_SECONDS:
+                time_padding = 3600
             
-            # if we've got a real value, we check it with the exclude
-            if local_min is not None:
-                # Now check if local_min is not valid
-                for tp in self.exclude:
-                    if tp.is_time_valid(local_min):
-                        still_loop = True
-                        # local_min + 60
-                        local_min = tp.get_next_invalid_time_from_t(local_min + 60)
-                        # No loop more than one year
-                        if local_min > original_t + 60 * 24 * 366 + 1:
-                            still_loop = False
-                            res = None
+            if still_loop:
+                local_min += time_padding
             
-            if not still_loop:  # We find a possible value
-                # We take the result the minimal possible
-                if res is None or local_min < res:
-                    res = local_min
+            # after max_time_to_search, stop.
+            if local_min > (original_start_time + max_period_to_search):
+                still_loop = False
+                local_min = None
         
-        # Ok, we update the cache...
-        self.invalid_cache[original_t] = local_min
+        # We update the cache if the max_period_to_search is far in future because if the max_period_to_search if too small we will not found the real next invalid
+        if max_period_to_search >= ONE_YEAR_AS_SECONDS:
+            self.invalid_cache[original_start_time] = local_min
         return local_min
     
     
@@ -472,14 +472,14 @@ class Timeperiod(Item):
     def resolve_daterange(self, dateranges, entry):
         # print "Trying to resolve ", entry
         
-        res = re.search('(\d{4})-(\d{2})-(\d{2}) - (\d{4})-(\d{2})-(\d{2}) / (\d+)[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(r'(\d{4})-(\d{2})-(\d{2}) - (\d{4})-(\d{2})-(\d{2}) / (\d+)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 1"
             (syear, smon, smday, eyear, emon, emday, skip_interval, other) = res.groups()
             dateranges.append(CalendarDaterange(syear, smon, smday, 0, 0, eyear, emon, emday, 0, 0, skip_interval, other))
             return
         
-        res = re.search('(\d{4})-(\d{2})-(\d{2}) / (\d+)[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(r'(\d{4})-(\d{2})-(\d{2}) / (\d+)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 2"
             (syear, smon, smday, skip_interval, other) = res.groups()
@@ -489,14 +489,14 @@ class Timeperiod(Item):
             dateranges.append(CalendarDaterange(syear, smon, smday, 0, 0, eyear, emon, emday, 0, 0, skip_interval, other))
             return
         
-        res = re.search('(\d{4})-(\d{2})-(\d{2}) - (\d{4})-(\d{2})-(\d{2})[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(r'(\d{4})-(\d{2})-(\d{2}) - (\d{4})-(\d{2})-(\d{2})[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 3"
             (syear, smon, smday, eyear, emon, emday, other) = res.groups()
             dateranges.append(CalendarDaterange(syear, smon, smday, 0, 0, eyear, emon, emday, 0, 0, 0, other))
             return
         
-        res = re.search('(\d{4})-(\d{2})-(\d{2})[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(r'(\d{4})-(\d{2})-(\d{2})[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 4"
             (syear, smon, smday, other) = res.groups()
@@ -506,14 +506,14 @@ class Timeperiod(Item):
             dateranges.append(CalendarDaterange(syear, smon, smday, 0, 0, eyear, emon, emday, 0, 0, 0, other))
             return
         
-        res = re.search('([a-z]*) ([\d-]+) ([a-z]*) - ([a-z]*) ([\d-]+) ([a-z]*) / (\d+)[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(r'([a-z]*) ([\d-]+) ([a-z]*) - ([a-z]*) ([\d-]+) ([a-z]*) / (\d+)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 5"
             (swday, swday_offset, smon, ewday, ewday_offset, emon, skip_interval, other) = res.groups()
             dateranges.append(MonthWeekDayDaterange(0, smon, 0, swday, swday_offset, 0, emon, 0, ewday, ewday_offset, skip_interval, other))
             return
         
-        res = re.search('([a-z]*) ([\d-]+) - ([a-z]*) ([\d-]+) / (\d+)[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(r'([a-z]*) ([\d-]+) - ([a-z]*) ([\d-]+) / (\d+)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 6"
             (t0, smday, t1, emday, skip_interval, other) = res.groups()
@@ -533,7 +533,7 @@ class Timeperiod(Item):
                 dateranges.append(MonthDayDaterange(0, 0, smday, 0, 0, 0, 0, emday, 0, 0, skip_interval, other))
                 return
         
-        res = re.search('([a-z]*) ([\d-]+) - ([\d-]+) / (\d+)[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(r'([a-z]*) ([\d-]+) - ([\d-]+) / (\d+)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 7"
             (t0, smday, emday, skip_interval, other) = res.groups()
@@ -553,7 +553,7 @@ class Timeperiod(Item):
                 dateranges.append(MonthDayDaterange(0, 0, smday, 0, 0, 0, 0, emday, 0, 0, skip_interval, other))
                 return
         
-        res = re.search('([a-z]*) ([\d-]+) ([a-z]*) - ([a-z]*) ([\d-]+) ([a-z]*) [\s\t]*([0-9:, -]+)', entry)
+        res = re.search(r'([a-z]*) ([\d-]+) ([a-z]*) - ([a-z]*) ([\d-]+) ([a-z]*) [\s\t]*([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 8"
             (swday, swday_offset, smon, ewday, ewday_offset, emon, other) = res.groups()
@@ -561,7 +561,7 @@ class Timeperiod(Item):
             dateranges.append(MonthWeekDayDaterange(0, smon, 0, swday, swday_offset, 0, emon, 0, ewday, ewday_offset, 0, other))
             return
         
-        res = re.search('([a-z]*) ([\d-]+) - ([\d-]+)[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(r'([a-z]*) ([\d-]+) - ([\d-]+)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 9"
             (t0, smday, emday, other) = res.groups()
@@ -581,7 +581,7 @@ class Timeperiod(Item):
                 dateranges.append(MonthDayDaterange(0, 0, smday, 0, 0, 0, 0, emday, 0, 0, 0, other))
                 return
         
-        res = re.search('([a-z]*) ([\d-]+) - ([a-z]*) ([\d-]+)[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(r'([a-z]*) ([\d-]+) - ([a-z]*) ([\d-]+)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 10"
             (t0, smday, t1, emday, other) = res.groups()
@@ -601,7 +601,7 @@ class Timeperiod(Item):
                 dateranges.append(MonthDayDaterange(0, 0, smday, 0, 0, 0, 0, emday, 0, 0, 0, other))
                 return
         
-        res = re.search('([a-z]*) ([\d-]+) ([a-z]*)[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(r'([a-z]*) ([\d-]+) ([a-z]*)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 11"
             (t0, swday_offset, t1, other) = res.groups()
@@ -614,7 +614,7 @@ class Timeperiod(Item):
                 dateranges.append(MonthWeekDayDaterange(0, smon, 0, swday, swday_offset, 0, emon, 0, ewday, ewday_offset, 0, other))
                 return
         
-        res = re.search('([a-z]*) ([\d-]+)[\s\t]+([0-9:, -]+)', entry)
+        res = re.search(r'([a-z]*) ([\d-]+)[\s\t]+([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 12"
             (t0, smday, other) = res.groups()
@@ -636,7 +636,7 @@ class Timeperiod(Item):
                 dateranges.append(MonthDayDaterange(0, 0, smday, 0, 0, 0, 0, emday, 0, 0, 0, other))
                 return
         
-        res = re.search('([a-z]*)[\s\t]+([0-9:, -]+)', entry)
+        res = re.search(r'([a-z]*)[\s\t]+([0-9:, -]+)', entry)
         if res is not None:
             # print "Good catch 13"
             (t0, other) = res.groups()
@@ -654,6 +654,9 @@ class Timeperiod(Item):
     
     # create daterange from unresolved param
     def explode(self, timeperiods):
+        # SEF-10098: all elements have a time period, defaulting with 24x7
+        # Adding a simple / fast test to manage elements using 24x7 like if they had no time period (in Scheduler)
+        self.time_is_always_valid = not self.exclude and TIMEPERIOD_24X7 == set(self.unresolved)
         for entry in self.unresolved:
             # print "Revolving entry", entry
             self.resolve_daterange(self.dateranges, entry)
