@@ -22,9 +22,9 @@ from shinkensolutions.api.synchronizer.source.abstract_module.listener_module im
 from shinkensolutions.system_tools import get_linux_local_addresses
 
 try:
-    from shinken.synchronizer.component.component_manager import component_manager
+    from shinken.synchronizer.component.component_manager_synchronizer import ComponentManagerSynchronizer
 except ImportError:
-    from synchronizer.component.component_manager import component_manager
+    from synchronizer.component.component_manager_synchronizer import ComponentManagerSynchronizer
 
 if TYPE_CHECKING:
     from shinken.misc.type_hint import Optional, Dict, Any, NoReturn
@@ -246,7 +246,7 @@ class BaseRESTListener(ListenerModule):
     
     def _init_data_provider_mongo(self):
         # type: () -> None
-        mongo_component = component_manager.get_mongo_component()
+        mongo_component = ComponentManagerSynchronizer.get_mongo_component()
         self.provider_mongo = DataProviderMongo(mongo_component, self.syncdaemon.database_cipher)
     
     
