@@ -4,22 +4,21 @@
 # Copyright (C) 2013-2022:
 # This file is part of Shinken Enterprise, all rights reserved.
 
+import datetime
 import json
 import os
 import re
 import threading
+import time
 from collections import OrderedDict, namedtuple
 from weakref import proxy as weak_ref
 
-import datetime
-import time
-
 from shinken.exceptions.business import ShinkenExceptionValueError, ShinkenExceptionKeyError
 from shinken.log import logger
-from shinken.misc.filter import get_all_my_visible_items, check_user_item_access
+from shinken.misc.filter import get_all_my_visible_items, check_user_item_access, get_count_of_my_visible_items
 from shinken.misc.perfdata import PerfDatas
 from shinken.misc.type_hint import TYPE_CHECKING
-from shinkensolutions.broker.monitoring_item_manager.helper import get_ack_on_item, get_downtime_on_item
+from shinkensolutions.broker.monitoring_item_manager.helper import get_ack_on_item, get_downtime_on_item, peek_in_set
 
 try:
     from cStringIO import StringIO
@@ -436,7 +435,7 @@ class FilterItem(object):
         self.page_size = None
         self.sorts = None
         self.full_sort_for_log = None
-        self.result_set_id = None
+        self.configuration_id_in_client = None
         self.filters = None
         self.full_filter_for_log = None
         self.flattened_view = True
@@ -657,7 +656,7 @@ class FilterItem(object):
             elif compare_type == 'string':
                 _match_tag = filter_values[0] in value
             elif compare_type == 'string_array':
-                _match_tag = True in [v in value for v in filter_values]
+                _match_tag = next((True for v in filter_values if v in value), False)
             elif compare_type == 'date':
                 filter_value = filter_values[0]
                 # SEF-10916 For the "next_check" property, the visu adds a "-" to the delay because it's in the future,
@@ -793,15 +792,8 @@ class FilterItem(object):
         logger.log_perf(start_time, u'get_list_api_part_all', u'sorts %s' % self.sorts)
     
     
-    def set_result_set_id(self, uuid):
-        # type: (unicode) -> None
-        # self.result_set_id = self.app.request.GET.get('configuration_id', '-1').strip()
-        self.result_set_id = uuid
-    
-    
     def set_flattened_mode(self, flattened_mode, checks_in_tree=False):
         # type: (bool, Optional[bool]) -> None
-        # self.flattened_view = self.app.request.GET.get('flatten_list', '0') == '1'
         self.flattened_view = bool(flattened_mode)
         self.checks_in_tree = bool(checks_in_tree)
     
@@ -988,15 +980,6 @@ class FilterItem(object):
             logger.print_stack()
             output_string.seek(0, os.SEEK_END)
             logger.error(u'Could not build JSON document from element list. Buffer size was : [%d]' % output_string.tell())
-            # if host_elements:
-            #     logger.error('Host elements nb : %d' % len(host_elements))
-            #     if len(host_elements) < 10:
-            #         logger.error("Hosts elements: %s" % str(host_elements))
-            #  if check_elements:
-            #      logger.error('Check elements nb : %d' % len(check_elements))
-            #      if len(check_elements) < 10:
-            #         for k, v in check_elements.items():
-            #              logger.error("Check elements: [%s] %d elements" % (str(k), len(v)))
             
             # Free memory if we could not complete
             output_string.close()
@@ -1017,74 +1000,54 @@ class FilterItem(object):
             log_prefix = u'%-22s ] [ get_data_visualisation_list' % thread_id
         
         items = self.monitoring_item_manager.get_all_hosts_and_services()
-        
-        configuration_id = u''
-        last_part_configuration_incarnation = self.monitoring_item_manager.get_last_part_configuration_incarnation()
-        if last_part_configuration_incarnation:
-            configuration_id = last_part_configuration_incarnation.get_uuid()
         full_nb_items_in_broker = len(items)
-        
         logger.log_perf(start_time, log_prefix, u'get_all_hosts_and_services len [%s]' % full_nb_items_in_broker)
         
+        filter_skip, items, nb_item_found = self.make_filter_skip(items)
+        
         # Filter with authorization
-        # TODO mark filter elements.
         if user:
+            items_count = get_count_of_my_visible_items(user, self.monitoring_item_manager)
             start_time = time.time()
-            items = get_all_my_visible_items(user, self.monitoring_item_manager)[:]
+            if not filter_skip:
+                items = get_all_my_visible_items(user, self.monitoring_item_manager)[:]
             logger.log_perf(start_time, log_prefix, u'only_related_to')
         else:
-            items = items[:]
+            items_count = self.monitoring_item_manager.get_count_items()
+            if not filter_skip:
+                items = items[:]
         
-        nb_elements_total = len(items)
         elements = []
         
-        # Values for selector
-        all_values = {}
-        if self.result_set_id is not None and self.result_set_id != configuration_id:
-            start_time = time.time()
-            all_values = list_all_values(items)
-            logger.log_perf(start_time, log_prefix, u'list_all_values')
-        
         start_time = time.time()
         hosts = {}
-        nb_element_root_problems = 0
-        nb_hosts_total = 0
-        nb_clusters_total = 0
-        nb_checks_total = 0
         for item in items:
-            if item.__class__.my_type == u'service':
-                nb_checks_total = nb_checks_total + 1
-                if item.host is None:
-                    logger.error(u'A service without host have been found id: %s  service_description: %s' % (item.instance_uuid, item.service_description))
-                    continue
-            else:
-                if item.got_business_rule:
-                    nb_clusters_total = nb_clusters_total + 1
-                else:
-                    nb_hosts_total = nb_hosts_total + 1
+            if item.__class__.my_type == u'host':
                 hosts[item.host_name] = item
-            if item.is_problem:
-                nb_element_root_problems += 1
-        logger.log_perf(start_time, log_prefix, u'count nb_element_root_problems')
+        logger.log_perf(start_time, log_prefix, u'build host dict')
         
         # Filter with filter parameters
-        timestamp_backend_processing_start = int(time.time())
         start_time = time.time()
         if self.filters:
             filters_contain_root_problems = u'true' in self.filters[0].get(u'is_root_problem', set([u'false']))
             if filters_contain_root_problems:
                 items = self.filter_root_problems(self.filters, items)
             
-            # normal filters
-            nb_found = [0, 0, 0]
-            items = self.filter_elements_with_search(items, self.filters, nb_found)
-            nb_hosts_found = nb_found[0]
-            nb_clusters_found = nb_found[1]
-            nb_checks_found = nb_found[2]
+            if filter_skip:
+                nb_hosts_found = nb_item_found[0]
+                nb_clusters_found = nb_item_found[1]
+                nb_checks_found = nb_item_found[2]
+            else:
+                # normal filters
+                nb_found = [0, 0, 0]
+                items = self.filter_elements_with_search(items, self.filters, nb_found)
+                nb_hosts_found = nb_found[0]
+                nb_clusters_found = nb_found[1]
+                nb_checks_found = nb_found[2]
         else:
-            nb_hosts_found = nb_hosts_total
-            nb_clusters_found = nb_clusters_total
-            nb_checks_found = nb_checks_total
+            nb_hosts_found = items_count[u'hosts']
+            nb_clusters_found = items_count[u'clusters']
+            nb_checks_found = items_count[u'checks']
         logger.log_perf(start_time, log_prefix, u'filter_elements_with_search ')
         
         nb_items_post_filter = len(items)
@@ -1277,26 +1240,11 @@ class FilterItem(object):
                         lost_elements.append(lost_element)
             logger.log_perf(start_time, log_prefix, u'Not found filters analysis')
         
-        ret = {
-            u'nb_element_total'                  : nb_elements_total,
-            u'nb_element_root_problems'          : nb_element_root_problems,
-            u'configuration_id'                  : configuration_id,
-            u'pages'                             : _pages,
-            u'timestamp_backend_processing_start': timestamp_backend_processing_start,
-            u'timestamp_backend_processing_end'  : int(time.time())
-        }
-        
-        # if self.flattened_view or not self.checks_in_tree:
-        #     ret['nb_element_filter'] = nb_element_return
-        
-        if all_values:
-            ret[u'all_values'] = all_values
-        
         elements_count = OrderedDict()
-        elements_count.update({u'nb_elements_total': nb_elements_total})
-        elements_count.update({u'nb_hosts_total': nb_hosts_total})
-        elements_count.update({u'nb_clusters_total': nb_clusters_total})
-        elements_count.update({u'nb_checks_total': nb_checks_total})
+        elements_count.update({u'nb_elements_total': items_count[u'all']})
+        elements_count.update({u'nb_hosts_total': items_count[u'hosts']})
+        elements_count.update({u'nb_clusters_total': items_count[u'clusters']})
+        elements_count.update({u'nb_checks_total': items_count[u'checks']})
         elements_count.update({u'nb_elements_filtered': nb_hosts_found + nb_clusters_found + nb_checks_found})
         elements_count.update({u'nb_hosts_filtered': nb_hosts_found})
         elements_count.update({u'nb_clusters_filtered': nb_clusters_found})
@@ -1404,6 +1352,132 @@ class FilterItem(object):
                 output_string.close()
     
     
+    def make_filter_skip(self, items):
+        # type: (List[Union[BrokerService, BrokerHost]]) -> Tuple[bool, List[Union[BrokerService, BrokerHost]], Tuple[int,int,int]]
+        filter_skip = False
+        item_found = None
+        if self.filters:
+            # -- SKIP : search one host by uuid
+            is_filter_on_one_host_by_uuid = (
+                    len(self.filters) == 1 and
+                    len(self.filters[0]) == 2 and
+                    u'extended_type' in self.filters[0] and
+                    u'uuid_parent' in self.filters[0] and
+                    (self.filters[0][u'extended_type'] & set([u'cluster', u'host'])) and
+                    len(self.filters[0][u'uuid_parent']) == 1
+            )
+            
+            if is_filter_on_one_host_by_uuid:
+                filter_skip = True
+                host_uuid = peek_in_set(self.filters[0][u'uuid_parent'])
+                item = self.monitoring_item_manager.get_host_by_uuid(host_uuid)
+                items = [item] if item and (not self.user or check_user_item_access(self.user, item.get_instance_uuid())) else []
+                
+                if not item:
+                    item_found = (0, 0, 0)
+                elif item.got_business_rule:
+                    item_found = (0, 1, 0)
+                else:
+                    item_found = (1, 0, 0)
+            
+            # -- SKIP : search one host by name
+            is_filter_on_one_host_by_name = (
+                    not filter_skip and
+                    len(self.filters) == 1 and
+                    len(self.filters[0]) == 2 and
+                    u'extended_type' in self.filters[0] and
+                    u'host_name' in self.filters[0] and
+                    (self.filters[0][u'extended_type'] & set([u'cluster', u'host'])) and
+                    len(self.filters[0][u'host_name']) == 1
+            )
+            
+            if is_filter_on_one_host_by_name:
+                filter_skip = True
+                host_name = peek_in_set(self.filters[0][u'host_name'])
+                item = self.monitoring_item_manager.get_host_case_insensitive(host_name)
+                items = [item] if item and (not self.user or check_user_item_access(self.user, item.get_instance_uuid())) else []
+                
+                if not item:
+                    item_found = (0, 0, 0)
+                elif item.got_business_rule:
+                    item_found = (0, 1, 0)
+                else:
+                    item_found = (1, 0, 0)
+            
+            # -- SKIP : search one check by uuid
+            is_filter_on_one_check_by_uuid = \
+                not filter_skip and \
+                len(self.filters) == 1 and \
+                (
+                        (
+                                len(self.filters[0]) == 3 and
+                                u'extended_type' in self.filters[0] and
+                                u'uuid_parent' in self.filters[0] and
+                                u'check_uuid' in self.filters[0] and
+                                (self.filters[0][u'extended_type'] & set([u'check', u'check_host', u'check_cluster'])) and
+                                len(self.filters[0][u'uuid_parent']) == 1 and
+                                len(self.filters[0][u'check_uuid']) == 1
+                        )
+                        or
+                        (
+                                len(self.filters[0]) == 2 and
+                                u'check_uuid' in self.filters[0] and
+                                u'uuid_parent' in self.filters[0] and
+                                len(self.filters[0][u'uuid_parent']) == 1 and
+                                len(self.filters[0][u'check_uuid']) == 1
+                        )
+                )
+            
+            if is_filter_on_one_check_by_uuid:
+                filter_skip = True
+                check_uuid = peek_in_set(self.filters[0][u'check_uuid'])
+                item = self.monitoring_item_manager.get_service_by_uuid(check_uuid)
+                items = [item] if item and (not self.user or check_user_item_access(self.user, item.get_instance_uuid())) else []
+                if item:
+                    item_found = (0, 0, 1)
+                else:
+                    item_found = (0, 0, 0)
+            
+            # -- SKIP : search one check by name
+            is_filter_on_one_check_by_name = \
+                not filter_skip and \
+                len(self.filters) == 1 and \
+                (
+                        (
+                                len(self.filters[0]) == 3 and
+                                u'extended_type' in self.filters[0] and
+                                u'host_name' in self.filters[0] and
+                                u'service_description' in self.filters[0] and
+                                (self.filters[0][u'extended_type'] & set([u'check', u'check_host', u'check_cluster'])) and
+                                len(self.filters[0][u'host_name']) == 1 and
+                                len(self.filters[0][u'service_description']) == 1
+                        )
+                        or (
+                                len(self.filters[0]) == 2 and
+                                u'host_name' in self.filters[0] and
+                                u'service_description' in self.filters[0] and
+                                len(self.filters[0][u'host_name']) == 1 and
+                                len(self.filters[0][u'service_description']) == 1
+                        )
+                )
+            
+            if is_filter_on_one_check_by_name:
+                filter_skip = True
+                host_name = peek_in_set(self.filters[0][u'host_name'])
+                check_name = peek_in_set(self.filters[0][u'service_description'])
+                item = self.monitoring_item_manager.get_service_case_insensitive(host_name, check_name)
+                items = [item] if item and (not self.user or check_user_item_access(self.user, item.get_instance_uuid())) else []
+                if item:
+                    item_found = (0, 0, 1)
+                else:
+                    item_found = (0, 0, 0)
+        
+        if filter_skip:
+            logger.info(u'[get_all_hosts_and_services] skip filter and found directly item')
+        
+        return filter_skip, items, item_found
+    
+    
     def _sort_lost_elements(self, lost_elements):
         if self.ALLOWED_OUTPUT:
             lost_elements.sort(key=lambda elt: (elt.get(self.ALLOWED_OUTPUT.get(u'host_name', u'None'), u''),
@@ -1555,12 +1629,19 @@ class RequestManagerLivedataV2(FilterItem):
         # type:(MonitoringItemManager, Optional[Contact], Optional[List[unicode]], Optional[List[unicode]], unicode, List[unicode], unicode, Optional[MultiDict, Dict[unicode, unicode]], unicode, bool) -> None
         super(RequestManagerLivedataV2, self).__init__(monitoring_item_manager, user)
         
-        self.update_modified_properties(mandatory_output_fields=mandatory_output_fields, user_allowed_output_field=user_allowed_output_field, user_filters=user_filters, user_allowed_filters=user_allowed_filters,
-                                        page_settings=page_settings, bottle_post=bottle_post, additional_format=additional_format, compute_not_found=compute_not_found)
+        self.update_modified_properties(
+            mandatory_output_fields=mandatory_output_fields,
+            user_allowed_output_field=user_allowed_output_field,
+            user_filters=user_filters,
+            user_allowed_filters=user_allowed_filters,
+            page_settings=page_settings,
+            bottle_post=bottle_post,
+            additional_format=additional_format,
+            compute_not_found=compute_not_found
+        )
     
     
-    def update_modified_properties(self, mandatory_output_fields=None, user_allowed_output_field=None, user_filters=None, user_allowed_filters=None, page_settings=u'', bottle_post=None, additional_format=u'',
-                                   compute_not_found=None):
+    def update_modified_properties(self, mandatory_output_fields=None, user_allowed_output_field=None, user_filters=None, user_allowed_filters=None, page_settings=u'', bottle_post=None, additional_format=u'', compute_not_found=None):
         # type:(Optional[List[unicode]], Optional[List[unicode]], unicode, List[unicode], unicode, Optional[MultiDict, Dict[unicode, unicode]], unicode, bool) -> None
         self.set_allowed_output(bottle_post=bottle_post, mandatory_fields=mandatory_output_fields, user_allowed_output_field=user_allowed_output_field)
         if user_allowed_filters:
