@@ -26,12 +26,21 @@ SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE = (function ( self ) {
         return document.querySelector( '#sortable-container-source-all' );
     };
     self.DOM.getSourceTaggerActionBar       = function () {
+        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
+            return document.querySelector( '#modules-type-area' );
+        }
         return document.querySelector( '.shinken-source-tagger-action-bar' );
     };
     self.DOM.getButtonSwitchAllSources      = function () {
+        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
+            return self.DOM.getSourceTaggerActionBar().querySelector( '#sort-list-source' );
+        }
         return self.DOM.getSourceTaggerActionBar().querySelector( '.shinken-button[data-name="page_main_switch_to_all_view" ]' );
     };
     self.DOM.getButtonSwitchSeparateSources = function () {
+        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
+            return self.DOM.getSourceTaggerActionBar().querySelector( '#view-sources' );
+        }
         return self.DOM.getSourceTaggerActionBar().querySelector( '.shinken-button[data-name="page_main_switch_to_type_view" ]' );
     };
     self.DOM.getInputSearch                 = function () {
@@ -71,7 +80,11 @@ SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE = (function ( self ) {
         return self.DOM.sourceLine( source_name ).querySelectorAll( ".shinken-content-nb-elements .shinken-nb-elements" );
     };
     self.DOM.sourceState                    = function ( source_name, source_state ) {
+        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
+            return self.DOM.sourceLine( source_name ).querySelector( 'td.column-state .' + source_state );
+        }
         return self.DOM.sourceLine( source_name ).querySelector( 'td.shinken-column-state .' + source_state );
+        
     };
     self.DOM.forceImportButton              = function ( source_name ) {
         return self.DOM.sourceLine( source_name ).querySelector( '.icon-play' );
@@ -171,10 +184,10 @@ SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE = (function ( self ) {
     self.ACTION.setSourceOrder              = function ( timeout, sorted_source_list ) {
         setTimeout( function () {
             var success = function ( _status, _data ) {
-                
+            
             };
             var error   = function ( err ) {
-                
+            
             };
             SHINKEN.COMUNICATION.requestGet( "http://" + SHINKEN.HIGHWAY.getHostName() + ":7766/api/sources/setorder?order=" + sorted_source_list.join( "," ), success, error );
         }, timeout );
