@@ -572,7 +572,11 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT_JSON = (function ( self ) {
                 break;
             case "00175-47":
                 _to_return[ "external_links" ][ "links" ].push( { "link_name": "test_auto" } );
+                _to_return[ "external_links" ][ "links" ][ 0 ][ "notifications" ]                                     = {};
+                _to_return[ "external_links" ][ "links" ][ 0 ][ "notifications" ][ "sound" ]                          = {};
                 _to_return[ "external_links" ][ "links" ][ 0 ][ "notifications" ][ "sound" ][ "enabled" ]             = value_to_force;
+                _to_return[ "external_links" ][ "links" ][ 0 ][ "notifications" ][ "visual" ]                         = {};
+                _to_return[ "external_links" ][ "links" ][ 0 ][ "notifications" ][ "visual" ][ "blink" ]              = {};
                 _to_return[ "external_links" ][ "links" ][ 0 ][ "notifications" ][ "visual" ][ "blink" ][ "enabled" ] = value_to_force;
                 break;
             case "00176-1":
