@@ -57,11 +57,16 @@ SHINKEN.TOOLS.TEST_AUTO_DAEMON = (function ( self ) {
         return _to_return;
     };
     self.COMMON.ACTION.editInConfigFile                      = function ( timeout, config_file_path, parameter, value ) {
+        var to_return     = 2000;
         var _command      = "grep " + parameter + " " + config_file_path;
         // First we verify if the parameter is already in the file
         var _grep_success = function ( _status, data ) {
             // The parameter is in the file, so we force its value to 1
             if ( data.rc === 0 ) {
+                if ( data.stdout.startsWith( "#", 4 ) ) {
+                    SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.replaceInFile( timeout, "# " + parameter + ".*", parameter + " " + value, config_file_path );
+                    return to_return;
+                }
                 SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.replaceInFile( timeout, parameter + ".*", parameter + " " + value, config_file_path );
             }
             // The parameter is not in the file, so we add it
@@ -73,7 +78,7 @@ SHINKEN.TOOLS.TEST_AUTO_DAEMON = (function ( self ) {
             }
         };
         SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.executePostCommand( timeout, _command, _grep_success, SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.COMMON.errorExecuteCommand );
-        return 2000;
+        return to_return;
     };
     self.COMMON.ACTION.createFileIfNotExists                 = function ( timeout, config_file_path, to_write ) {
         var _command    = "ls -al " + config_file_path;
@@ -165,6 +170,9 @@ SHINKEN.TOOLS.TEST_AUTO_DAEMON = (function ( self ) {
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, daemon_name.toUpperCase() + '.ACTION.restart' );
         setTimeout( function () {
             SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
+            if ( must_reload ) {
+                __do_next = false;
+            }
             SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.executePostCommand( 0, "service shinken-" + daemon_name + " -d restart", function () {
                 if ( must_reload ) {
                     SHINKEN.HIGHWAY.refreshCurrentPage();
@@ -210,6 +218,15 @@ SHINKEN.TOOLS.TEST_AUTO_DAEMON = (function ( self ) {
         }, timeout );
         return 1000;
     };
+    self.COMMON.TEST.activateWeatherModule                   = function ( timeout ) {
+        if ( __version_shinken !== SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
+            SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.addModuleIfNotSet( timeout, "/etc/shinken/modules/webui.cfg", "webui-module-service-weather" );
+            SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.upsertDocumentToMongo( timeout, "webui", "service_weather__weather_data", SHINKEN.TOOLS.TEST_AUTO.WEATHER_DEFAULT_UUID, SHINKEN.TOOLS.TEST_AUTO.WEATHER_DEFAULT_MONGO_DOCUMENT );
+            SHINKEN.TOOLS.TEST_AUTO_DAEMON.BROKER.ACTION.restart( timeout, false );
+            SHINKEN.TOOLS.TEST_AUTO_DAEMON.ARBITER.ACTION.restart( timeout, false );
+        }
+        return 5000;
+    };
     self.COMMON.TEST.isLoggedOnAllDaemon                     = function ( timeout, to_grep, only_last_hour ) {
         return self.SCHEDULER.TEST.isLogged( timeout, to_grep, only_last_hour ) +
                self.ARBITER.TEST.isLogged( timeout, to_grep, only_last_hour ) +
@@ -287,6 +304,15 @@ SHINKEN.TOOLS.TEST_AUTO_DAEMON = (function ( self ) {
         
         return 15000;
     };
+    self.COMMON.TEST.fileNotExist                            = function ( timeout, path_to_file, isExist, _error ) {
+        var _succes = function ( _status, data ) {
+            if ( data.rc === 0 ) {
+                SHINKEN.TOOLS.TEST_AUTO.addError( "The file " + path_to_file + " exists when it should not be" );
+            }
+        };
+        var command = "ls " + path_to_file;
+        SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.executePostCommand( timeout, command, _succes, _error );
+    };
     self.COMMON.ACTION.addModuleIfNotSet                     = function ( timeout, config_file_path, module_name ) {
         var _command      = "grep -E '^\\s*modules.*" + module_name + "' " + config_file_path;
         // First we verify if the module is already set
@@ -328,6 +354,15 @@ SHINKEN.TOOLS.TEST_AUTO_DAEMON = (function ( self ) {
         SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.executePostCommand( timeout, _command, _success, SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.COMMON.errorExecuteCommand );
         return 10000;
     };
+    self.SYNCHRONIZER.ACTION.disableEncryption               = function ( timeout ) {
+        var _command = "shinken-protected-fields-encryption-disable -y";
+        var _success = function ( _status, data ) {
+        
+        };
+        
+        SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.executePostCommand( timeout, _command, _success, SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.COMMON.errorExecuteCommand );
+        return 10000;
+    };
     self.SYNCHRONIZER.ACTION.removeFieldInProtectedList      = function ( timeout, field_to_remove ) {
         var _command = "expect -c 'spawn shinken-protected-fields-data-manage -r " + field_to_remove + " ; expect \"(Y/n)\" ; send -- \"Y\\r\"'" + field_to_remove;
         var _success = function ( _status, data ) {
