@@ -1,14 +1,36 @@
 SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
-    self.DOM                                  = {};
-    self.TEST                                 = {};
-    self.ACTION                               = {};
+    self.DOM                          = {};
+    self.TEST                         = {};
+    self.ACTION                       = {};
     //********************************************  GET DOM ELEMENT   **************************************************//
-    self.DOM.getButtonSave                    = function () {
-        return document.getElementById( 'id-shinken-btn-save' );
+    self.DOM.document                 = function ( window ) {
+        return window ? window.document : document;
     };
-    self.DOM.buttonDelete                     = function () {
-        return document.getElementById( 'id-shinken-btn-remove' );
+    self.DOM.getButtonSave            = function ( window ) {
+        return self.DOM.document( window ).getElementById( 'id-shinken-btn-save' );
     };
+    self.DOM.getButtonDelete          = function ( window ) {
+        return self.DOM.document( window ).getElementById( 'id-shinken-btn-remove' );
+    };
+    self.DOM.getButtonSubmitToStaging = function ( window ) {
+        return self.DOM.document( window ).getElementById( 'id-shinken-btn-submit-to-staging' );
+    };
+    self.DOM.getButtonAcceptPropose   = function ( window ) {
+        return self.DOM.document( window ).querySelector( '#element-btn-apply_work_area .btn-apply_work_area' );
+    };
+    self.DOM.workFlowManagerButton    = function ( workflow_name, is_window ) {
+        var _css_selector = '.shinken-row-workflow-title ';
+        switch ( workflow_name ) {
+            case MANAGER.CONST.STATE.WORK_FLOW.STAGING:
+                _css_selector += '.shinken-workflow-direct-staging-cell';
+                break;
+            case MANAGER.CONST.STATE.WORK_FLOW.WORKING_AREA:
+                _css_selector += '.shinken-workflow-working-area-cell';
+                break;
+        }
+        return self.DOM.document( is_window ? SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.instance : null ).querySelector( _css_selector );
+    };
+    
     //********************************************  GETTER SETTER   **************************************************//
     self.getSavingLog                         = function () {
         return document.getElementById( "saving-log" );
@@ -17,20 +39,6 @@ SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
         return self.getSavingLog().querySelector( ".saving-log-title" );
     };
     //********************************************  CHANGE DATABASE   **************************************************//
-    self.forceImportGregIsDead                = function ( timeout ) {
-        setTimeout( function () {
-            $.ajax( {
-                url    : '/api/sources/forceimport/test_auto?ts=' + DATE_TIME.getTimestampNow(),
-                success: function ( data ) {
-                    console.log( "[data]", data );
-                },
-                error  : function ( data, txt ) {
-                    console.log( 'Got bad result for' + data );
-                }
-            } );
-        }, timeout );
-        return 10000;
-    };
     self.deleteElement                        = function ( timeout, shinken_element, result_expected, in_working_area, extra_label ) {
         var _to_return = 2000;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, in_working_area ? 'deleteElement in workarea' : 'deleteElement', shinken_element.getUUID() );
@@ -189,13 +197,14 @@ SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
             case "00133-4":
                 return SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.HOSTS.TEST_AUTO_VALID_132.URL;
             case "00139-1":
+            case "00215-1":
                 return '/element/q/hosts/save/00000000000000000000000000000003?bypass_work_area=1';
-            case "00163-2":
-            case "00163-6":
+            case "00163-5":
+            case "00163-9":
                 return '/element/q/hosts/save_in_work_area/00000000000000000000000000000163?submit_to_stagging=1';
-            case "00163-4":
-                return '/element/q/hosts/reject_submit/00000000000000000000000000000163?ts=' + Date.now();
             case "00163-7":
+                return '/element/q/hosts/reject_submit/00000000000000000000000000000163?ts=' + Date.now();
+            case "00163-10":
                 return '/element/q/hosts/apply_work_area/00000000000000000000000000000163?ts=' + Date.now();
             case "00177-1":
                 return SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CLUSTER.TEST_AUTO_VALID_CLUSTER.URL;
@@ -205,6 +214,9 @@ SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
                 return '/element/q/hosts/unlock_work_area/00000000000000000000000000000001';
             case "00183-7":
                 return '/element/q/contacts/save/35000000000000000000000000000000';
+            case "00239-1":
+            case "00239-3-2":
+                return '/element/q/hosttpls/save/12000000000000000000000000000000?bypass_work_area=1';
             default:
                 return '/element/q/hosts/save/00000000000000000000000000000001?bypass_work_area=1';
             
@@ -713,6 +725,22 @@ SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
                 _to_return[ "address" ]   = "localhost";
                 _to_return[ "_SE_UUID" ]  = "core-hosts-00000000000000000000000000000227";
                 break;
+            case "00215-1":
+                _to_return[ "_id" ]       = "00000000000000000000000000000003";
+                _to_return[ "host_name" ] = "00003_test_auto";
+                _to_return[ "use" ]       = "00003_test_auto_1,00003_test_auto_2";
+                break;
+            case "00239-1":
+                _to_return[ "_id" ]      = "12000000000000000000000000000000";
+                _to_return[ "name" ]     = "test_auto_valid";
+                _to_return[ "register" ] = "0";
+                _to_return[ "use" ]      = "shinken-full";
+                break;
+            case "00239-3-2":
+                _to_return[ "_id" ]      = "12000000000000000000000000000000";
+                _to_return[ "name" ]     = "test_auto_valid";
+                _to_return[ "register" ] = "0";
+                break;
             default:
                 _to_return[ "_id" ]          = "00000000000000000000000000000001";
                 _to_return[ "host_name" ]    = "00001_test_auto";
@@ -730,7 +758,6 @@ SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
         item_dump[ 'protect_fields__activate_interface_encryption' ] = SHINKEN.TOOLS.ENCRYPTION.isDatabaseEncryptionActivated();
         item_dump[ 'protect_fields__are_viewable_by_admin_si' ]      = SHINKEN.TOOLS.ENCRYPTION.isProtectedFieldsAreViewableByAdminSi();
         item_dump[ 'item' ]                                          = JSON.stringify( data );
-        
         if ( !url ) {
             return;
         }
@@ -813,7 +840,7 @@ SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
     self._sendElementToListenerTestAuto       = function ( element, element_type ) {
         $.ajax( {
             type       : "PUT",
-            url        : "http://" + SHINKEN.HIGHWAY.getHostName() + ":" + SOURCE__PORT__LISTENER_TEST_AUTO +"/shinken/listener-test-auto/v1/" + element_type + "/",
+            url        : "http://" + SHINKEN.HIGHWAY.getHostName() + ":" + SOURCE__PORT__LISTENER_TEST_AUTO + "/shinken/listener-test-auto/v1/" + element_type + "/",
             contentType: "application/json",
             headers    : {
                 "Authorization": "Basic " + btoa( "Shinken" + ":" + "Shinken" )
@@ -829,19 +856,19 @@ SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
         } );
     };
     //********************************************  ACTION   **************************************************//
-    self.ACTION.goToMode                      = function ( timeout, workflow_mode ) {
+    self.ACTION.goToMode                      = function ( timeout, workflow_mode, is_window ) {
         setTimeout( function () {
-            MANAGER.WorkFlowManager.clickOnTabArea( workflow_mode );
+            self.DOM.workFlowManagerButton( workflow_mode, is_window ).click();
         }, timeout );
-        return 4000;
+        return 200;
     };
     //********************************************  EDITION ELEMENT SINGLE   **************************************************//
-    self.saveWithButtonSubmitToStagging       = function ( timeout ) {
+    self.saveWithButtonSubmitToStagging       = function ( timeout, window ) {
         var _to_return = 2000;
-        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'saveWithButtonSubmitToStagging' );
+        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'saveWithButtonSubmitToStaging' );
         setTimeout( function () {
             SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
-            var _save_button = document.getElementById( 'id-shinken-btn-submit-to-staging' );
+            var _save_button = self.DOM.getButtonSubmitToStaging( window );
             SHINKEN.TOOLS.TEST_AUTO.__isVisible( _save_button, '' );
             if ( !SHINKEN.TOOLS.TEST_AUTO.hasMessage() ) {
                 _save_button.click();
@@ -853,18 +880,28 @@ SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
             }
             SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
         }, timeout );
-        return 2000;
+        return _to_return;
     };
     self.ACTION.saveWithButtonImport          = function ( timeout, escape_do_next ) {
         return self.ACTION.saveWithButtonSave( timeout, escape_do_next );
     };
-    self.ACTION.saveWithButtonSave            = function ( timeout, escape_do_next ) {
+    self.ACTION.saveWithButtonSave            = function ( timeout, escape_do_next, window ) {
+        __do_next      = false;
         var _to_return = 2000;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'saveWithButtonSave' );
         setTimeout( function () {
             SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
-            var _save_button = self.DOM.getButtonSave();
+            var _save_button = self.DOM.getButtonSave( window );
             SHINKEN.TOOLS.TEST_AUTO.__isVisible( _save_button, '' );
+            SHINKEN.TOOLS.TEST_AUTO.buildMessage( 0 );
+            if ( !escape_do_next ) {
+                SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
+            }
+            else {
+                if ( __window_phase ) {
+                    SHINKEN.HIGHWAY.changeUrl();
+                }
+            }
             if ( !SHINKEN.TOOLS.TEST_AUTO.hasMessage() ) {
                 _save_button.click();
                 SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
@@ -873,9 +910,6 @@ SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
                 SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "NOK" );
                 SHINKEN.TOOLS.TEST_AUTO.addError( "Le test comporte des erreurs, la dernière action n'a pas été faites" );
             }
-            if ( !escape_do_next ) {
-                SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
-            }
             
         }, timeout );
         return _to_return;
@@ -888,7 +922,7 @@ SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
             confirm         = function () {
                 return true;
             };
-            var dom_element = self.DOM.buttonDelete();
+            var dom_element = self.DOM.getButtonDelete();
             if ( !SHINKEN.TOOLS.TEST_AUTO.hasMessage() ) {
                 SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, dom_element );
                 SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
@@ -915,15 +949,16 @@ SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
         }, timeout );
         return 2000;
     };
-    self.saveWithButtonAcceptPropose          = function ( timeout ) {
-        var _to_return = 2000;
+    self.saveWithButtonAcceptPropose          = function ( timeout, window ) {
+        var _to_return = 4000;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'saveWithButtonAcceptPropose' );
+        
         setTimeout( function () {
             SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
             SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT_EDITION.ACTION.navigateInTab( 0, WINDOW.CONST.ELEMENT.PROPOSED );
         }, timeout / 2 );
         setTimeout( function () {
-            var _save_button = document.querySelector( '#element-btn-apply_work_area .btn-apply_work_area' );
+            var _save_button = self.DOM.getButtonAcceptPropose( window );
             SHINKEN.TOOLS.TEST_AUTO.__isVisible( _save_button, '' );
             if ( !SHINKEN.TOOLS.TEST_AUTO.hasMessage() ) {
                 _save_button.click();
@@ -935,7 +970,7 @@ SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT = (function ( self ) {
             }
             SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
         }, timeout );
-        return 4000;
+        return _to_return;
     };
     //********************************************  EDITION ELEMENT SINGLE   **************************************************//
     self.TEST.numberOfPropertyToSave          = function ( timeout, nb_element ) {
