@@ -114,7 +114,22 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
     },
     "00020"   : {
         testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
-        address        : "/elements/hosts/00000000000000000000000000000020"
+        phases         : 13,
+        address        : [
+            "/elements/hosts/00000000000000000000000000000020",
+            "/elements/hosts/00000000000000000000000000000020?tab=datas",
+            "/elements/hosts/00000000000000000000000000000020?tab=datas",
+            "/elements/hosts/00000000000000000000000000000020?tab=datas",
+            "/elements/hosts/00000000000000000000000000000020?tab=datas",
+            "/elements/hosts/00000000000000000000000000000020?tab=datas",
+            "/elements/hosts/00000000000000000000000000000020?tab=datas",
+            "/elements/hosts/00000000000000000000000000000020?tab=datas",
+            "/elements/hosts/00000000000000000000000000000020?tab=datas",
+            "/elements/hosts/00000000000000000000000000000020?tab=datas",
+            "/elements/hosts/00000000000000000000000000000020?tab=datas",
+            "/elements/hosts/00000000000000000000000000000020?tab=datas",
+            "/elements/hosts/00000000000000000000000000000020?tab=datas"
+        ]
     },
     "00021"   : {
         phases         : 3,
@@ -176,8 +191,7 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
             "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
             "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
             "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
-            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
-            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
+            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER + "?tab=tab-detail-last-run&filter=name:jo",
             "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
             "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
             "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
@@ -661,8 +675,13 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
     },
     "00136"   : {
         testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
-        address        : "/elements/hosts/03000000000000000000000000000000",
-        phases         : 3
+        address        : [
+            "/main",
+            "/elements/hosts/03000000000000000000000000000000",
+            "/elements/hosts/03000000000000000000000000000000",
+            "/elements/hosts/03000000000000000000000000000000",
+            "/main"
+        ]
     },
     "00137"   : {
         testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
@@ -670,7 +689,11 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
     },
     "00138"   : {
         testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
-        address        : "/elements/serviceshosts/23000000000000000000000000000000"
+        address        : [
+            "/main",
+            "/elements/serviceshosts/23000000000000000000000000000000",
+            "/main"
+        ]
     },
     "00139"   : {
         testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
@@ -883,7 +906,7 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
         ]
     },
     "00152"   : {
-        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : [
             "/main",
             "/elements/hosts/00000000000000000000000000000152?new=1",
@@ -1043,7 +1066,7 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
         ]
     },
     "00157"   : {
-        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : [
             "/main",
             "/elements/hosts/00000000000000000000000000000157?new=1",
@@ -1078,7 +1101,7 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
         ]
     },
     "00158"   : {
-        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        :
             [
                 "/sources/server-analyzer?tab=tab-configuration",
@@ -1099,16 +1122,21 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
         address        : "/sources/listener-shinken?tab=tab-configuration"
     },
     "00161"   : {
-        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE, testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
+        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : "/sources/cfg-file-shinken?tab=tab-configuration"
     },
     "00162"   : {
-        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE, testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
+        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : "/sources/discovery?tab=tab-configuration"
     },
     "00163"   : {
-        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : [
+            "/main",
+            "/elements/elements?filter=type%3A%3D\"nouveau\"~name%3A!new&start=000&end=1000",
+            "/elements/elements?filter=type%3A%3D\"nouveau\"~name%3A!new&start=000&end=1000",
             "/elements/working_area/hosts/00000000000000000000000000000163?new=1",
             "/elements/working_area/hosts/00000000000000000000000000000163",
             "/elements/working_area/hosts/00000000000000000000000000000163",
@@ -1277,7 +1305,11 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
     },
     "00179"   : {
         testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
-        address        : "/elements/hosts/00000000000000000000000000000179"
+        address        : [
+            "/main",
+            "/elements/hosts/00000000000000000000000000000179",
+            "/main"
+        ]
     },
     "00180"   : {
         testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
@@ -1366,7 +1398,7 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
     },
     "00189"   : {
         version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
-        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : [
             "/elements/hosts/00000000000000000000000000000001",
             "/elements/hosts/00000000000000000000000000000001",
@@ -1433,10 +1465,11 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
     },
     "00197"   : {
         version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
-        port           : [7767, 7766, 7767, 7766],
-        phases         : 4,
+        port           : [7766, 7767, 7766, 7767, 7766],
+        phases         : 5,
         testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : [
+            "/main",
             "/static/ui/index.html",
             "/main",
             "/static/ui/index.html",
@@ -1512,6 +1545,7 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
         port           : 7766,
         testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : [
+            "/main",
             "/sources/server-analyzer?tab=tab-configuration",
             "/sources/server-analyzer?tab=tab-configuration",
             "/sources/server-analyzer?tab=tab-network-scan",
@@ -1583,7 +1617,7 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
     "00211"   : {
         version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
         port           : 7766,
-        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : [
             "/elements/working_area/hosts?filter=host_name:211",
             "/elements/working_area/hosts?filter=host_name:211",
@@ -1615,7 +1649,7 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
     "00214"   : {
         version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
         port           : 7766,
-        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : [
             "/sources/server-analyzer?tab=tab-analyzer-template-mapping",
             "/sources/server-analyzer?tab=tab-analyzer-template-mapping"
@@ -1624,15 +1658,21 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
     },
     "00215"   : {
         version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
-        port           : [7767, 7766, 7766, 7766, 7767],
+        port           : [7766, 7766, 7766, 7767, 7766, 7766, 7766, 7767],
         testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : [
-            "/static/ui/index.html",
+            "/elements/hosts/00000000000000000000000000000003",
+            "/apply",
+            "/apply",
+            "/static/ui/index.html#/list/all"
+        ],
+        address_window : [
             "/elements/hosts/00000000000000000000000000000003",
             "/apply",
             "/apply",
             "/static/ui/index.html"
         ],
+        port_window    : [7766, 7766, 7766, 7766],
         subject        : "ui_visualisation,list_filter"
     },
     "00216"   : {
@@ -1733,12 +1773,16 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
         port           : 7766,
         testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : [
+            "/apply",
             "/apply",
             "/elements/hosts/00000000000000000000000000000002",
             "/elements/hosts/00000000000000000000000000000002",
             "/apply",
             "/apply",
             "/apply",
+            "/apply",
+            "/elements/hosts/00000000000000000000000000000002",
+            "/elements/hosts/00000000000000000000000000000002",
             "/apply"
         ],
         subject        : "apply_in_production"
@@ -1767,7 +1811,7 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
     "00228"   : {
         version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
         port           : 7766,
-        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : ["/main", "/elements/add/contact"],
         subject        : "shinken_protected_fields"
     },
@@ -1815,7 +1859,7 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
     "00233"   : {
         version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
         port           : 7766,
-        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : [
             "/main",
             "/elements/hosts/03000000000000000000000000000000", // HOST
@@ -1860,20 +1904,82 @@ SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
     },
     "00235"   : {
         version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
-        port           : 7766,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
+        port           : [7766, 7766, 7766, 7767, 7767, 7767],
         address        : [
             "/main",
             "/elements/working_area/hosts",
-            "/elements/working_area/hosts"
+            "/elements/working_area/hosts",
+            "/static/ui/index.html",
+            "/static/ui/index.html#/hosts/00000000000000000000000000000235/manage",
+            "/static/ui/index.html#/hosts/00000000000000000000000000000235/checks"
         ],
         subject        : "notes_url"
     },
     "00236"   : {
         version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         port           : [7766, 7767, 7767, 7766, 7767, 7767],
         address        : ["/main", "/static/ui/index.html#/", "/static/ui/index.html#/list/", "/main", "/static/ui/index.html#/", "/static/ui/index.html#/list/"],
         subject        : "add_to_favorite"
     },
+    "00237"   : {
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
+        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
+        port           : 7766,
+        address        : ["/main", "/main"],
+        subject        : "secretsdump.py"
+    },
+    "00238"   : {
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
+        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
+        port           : 7766,
+        address        : ["/main", "/main", "/main"],
+        subject        : "test admin si's permissions on apply page"
+    },
+    "00239"   : {
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
+        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
+        port           : 7766,
+        address        : [
+            "/elements/hosts/00000000000000000000000000000001",
+            "/elements/hosts/00000000000000000000000000000001",
+            "/elements/hosts/00000000000000000000000000000001"
+        ],
+        subject        : "Test result try check long output is not in short output"
+    },
+    "00243"   : {
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
+        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
+        port           : [7766,7766,7766,7766,7766,7766,7767,
+                          7767,7766,7766],
+        address        : [
+            "/elements/contacts/35000000000000000000000000000000",
+            "/elements/contacts/35000000000000000000000000000000",
+            "/apply",
+            "/apply",
+            "/login",
+            "/login",
+            "/static/ui/index.html#/",
+            "/static/ui/index.html#/",
+            "/elements/contacts/35000000000000000000000000000000",
+            "/apply",
+            "/apply",
+        ],
+        subject        : "Test if the duration of the authentification works SEF-10949"
+    },
+    "00242"   : {
+        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
+        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
+        port           : 7766,
+        address        : [
+            "/elements/hosts/00000000000000000000000000000242",
+            "/elements/hosts/00100000000000000000000000000242",
+            "/elements/hosts/00200000000000000000000000000242",
+            "/elements/hosts/00300000000000000000000000000242"
+        ],
+        subject        : "Test result try check result threshold for pack Switch"
+    },
     "delete_1": {
         testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
         address        : "/elements/elements?filter=sources:test_auto&shinken_test_auto=delete1"
