@@ -192,7 +192,7 @@ SHINKEN.TOOLS.TEST_AUTO       = (function ( self ) {
             extra_label = "";
         }
         if ( text !== string_expected ) {
-            SHINKEN.TOOLS.TEST_AUTO.addError( extra_label + "le text dans <b>" + in_label + "</b> n'est pas égale à [<b>[" + SHINKEN.TOOLS.STRING.cleanXss( string_expected ) + "]</b>] ==> [" + SHINKEN.TOOLS.STRING.cleanXss( text ) + "]" );
+            SHINKEN.TOOLS.TEST_AUTO.addError( extra_label + "le text dans <b>" + in_label + "</b> n'est pas égale à [<b>" + SHINKEN.TOOLS.STRING.cleanXss( string_expected ) + "</b>] ==> [" + SHINKEN.TOOLS.STRING.cleanXss( text ) + "]" );
         }
     };
     self.__containsText           = function ( text, value_to_test, in_label, extra_label, reverse ) {
@@ -419,6 +419,12 @@ SHINKEN.TOOLS.TEST_AUTO       = (function ( self ) {
         } );
         dom_element.dispatchEvent( event );
     };
+    self.sleep                          = function ( timeout ) {
+        setTimeout( function () {
+            console.log( "" );
+        }, timeout );
+        return 5000;
+    };
     return self;
 })( SHINKEN.TOOLS.TEST_AUTO || {} );
 SHINKEN.TOOLS.TEST_AUTO_PHASE = (function ( self ) {
