@@ -9,12 +9,14 @@
 //      python3.9 flask_server_add_daemons_route.py
 
 
-var __is_log_mute       = SHINKEN.HIGHWAY.getParams( 'mute' );
-var __shinken_test_type = SHINKEN.HIGHWAY.getParams( 'shinken_test_auto' );
-var __is_single         = SHINKEN.HIGHWAY.getParams( 'single' );
-var __phase             = parseInt( SHINKEN.HIGHWAY.getParams( 'phase' ) ) || 1;
-var _has_script_error   = 0;
-var __do_next           = true;
+var __is_log_mute        = SHINKEN.HIGHWAY.getParams( 'mute' );
+var __shinken_test_type  = SHINKEN.HIGHWAY.getParams( 'shinken_test_auto' );
+var __is_single          = SHINKEN.HIGHWAY.getParams( 'single' );
+var __phase              = parseInt( SHINKEN.HIGHWAY.getParams( 'phase' ) ) || 1;
+var __window_phase       = parseInt( SHINKEN.HIGHWAY.getParams( 'window_phase' ) ) || '';
+var _has_script_error    = 0;
+var __do_next            = true;
+var __time_start_for_log = Date.now();
 
 var _current;
 var _property_name;
@@ -49,21 +51,21 @@ var doActionWhenReadyTestAuto = function () {
             return;
         }
     }
-    
-    switch ( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ __shinken_test_type ].testable_status ) {
-        case SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE :
-            SHINKEN.TOOLS.TEST_AUTO.addError( "test exclude" );
-            SHINKEN.TOOLS.TEST_AUTO.MakeFinalAction( _timeout );
-            return;
-        case SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.DISCONTINUED :
-            SHINKEN.TOOLS.TEST_AUTO.addError( "test discontinued" );
-            SHINKEN.TOOLS.TEST_AUTO.MakeFinalAction( _timeout );
-            break;
-        case SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.IN_DEVELOPMENT :
-            SHINKEN.TOOLS.TEST_AUTO.addError( "test in development" );
-            SHINKEN.TOOLS.TEST_AUTO.MakeFinalAction( _timeout );
-            break;
-        
+    if ( !__window_phase ) {
+        switch ( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ __shinken_test_type ].testable_status ) {
+            case SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE :
+                SHINKEN.TOOLS.TEST_AUTO.addError( "test exclude" );
+                SHINKEN.TOOLS.TEST_AUTO.MakeFinalAction( _timeout );
+                return;
+            case SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.DISCONTINUED :
+                SHINKEN.TOOLS.TEST_AUTO.addError( "test discontinued" );
+                SHINKEN.TOOLS.TEST_AUTO.MakeFinalAction( _timeout );
+                break;
+            case SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.IN_DEVELOPMENT :
+                SHINKEN.TOOLS.TEST_AUTO.addError( "test in development" );
+                SHINKEN.TOOLS.TEST_AUTO.MakeFinalAction( _timeout );
+                break;
+        }
     }
     
     switch ( __shinken_test_type ) {
@@ -126,11 +128,7 @@ var doActionWhenReadyTestAuto = function () {
             }
             break;
         case "00031":
-            //TEST LINKER
-            if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.ALPHA || __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
-                __phase = 70;
-                break;
-            }
+            
             switch ( __phase ) {
                 case 1:
                     ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.switchListSourceDisplay( _timeout, true ) );
@@ -146,7 +144,7 @@ var doActionWhenReadyTestAuto = function () {
                     __do_next = false;
                     _timeout += 1000;
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "sync_name", "TEST_AUTO_1" ) );
-                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "address", "172.16.0.180" ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "address", "51.15.206.188" ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "contact_name", "Shinken" ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "password", "Shinken" ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.save( _timeout ) );
@@ -168,7 +166,6 @@ var doActionWhenReadyTestAuto = function () {
                     _timeout += 1000;
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "prefix", "TEST_AUTO_2" ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.save( _timeout ) );
-                    __do_next = false;
                     break;
                 case 7:
                     __do_next = false;
@@ -176,59 +173,45 @@ var doActionWhenReadyTestAuto = function () {
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 1, [COMPONENT.CONST.BTN_STATE.ON] ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnAddDistantSynchronizer( _timeout ) );
                     break;
-                //TODO A REPENSER A PARTIR DE LA...
                 case 8:
-                    //__do_next = false;
-                    //_timeout += 1000;
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "sync_name", "TEST_AUTO_3" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "address", "172.16.0.180" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "contact_name", "Shinken" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "password", "Shinken" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.save( _timeout ) );
+                    _timeout += 1000;
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "sync_name", "TEST_AUTO_1" ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "address", "51.15.206.188" ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "contact_name", "Shinken" ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "password", "Shinken" ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.save( _timeout, true ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.hasFormError( _timeout ) );
                     break;
                 case 9:
-                    //__do_next = false;
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 2, [COMPONENT.CONST.BTN_STATE.ON, COMPONENT.CONST.BTN_STATE.ON] ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnActivateDistantSynchronizer( _timeout, "TEST_AUTO_3" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 2, [COMPONENT.CONST.BTN_STATE.ON, COMPONENT.CONST.BTN_STATE.OFF] ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnActivateDistantSynchronizer( _timeout, "TEST_AUTO_1" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 2, [COMPONENT.CONST.BTN_STATE.OFF, COMPONENT.CONST.BTN_STATE.OFF] ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnActivateDistantSynchronizer( _timeout, "TEST_AUTO_1" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnActivateDistantSynchronizer( _timeout, "TEST_AUTO_3" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 2, [COMPONENT.CONST.BTN_STATE.ON, COMPONENT.CONST.BTN_STATE.ON] ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnUpdateDistantSynchronizer( _timeout, "TEST_AUTO_3" ) );
+                    __do_next = false;
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.forceImport( _timeout ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_PHASE.doNextWhen( _timeout, 'MANAGER.__instance_source_distributor.findSource("' + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER + '").fully_merged' ) );
                     break;
                 case 10:
-                    //__do_next = false;
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.delete( _timeout ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-detail-last-run" ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerListLength( _timeout, 1 ) );
                     break;
                 case 11:
-                    //__do_next = false;
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 1, [COMPONENT.CONST.BTN_STATE.ON] ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnUpdateDistantSynchronizer( _timeout, "TEST_AUTO_1" ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 1, [COMPONENT.CONST.BTN_STATE.ON] ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnUpdateDistantSynchronizer( _timeout, "TEST_AUTO_1" ) );
                     break;
                 case 12:
-                    //__do_next = false;
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValueBoolean( _timeout, "enabled", 0 ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.save( _timeout ) );
+                    __do_next = false;
+                    _timeout += 1000;
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.delete( _timeout ) );
+                    //____( SHINKEN.TOOLS.TEST_AUTO_PHASE.doNextWhen( _timeout, 'SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.delete(' + _timeout + ')' ) );
                     break;
                 case 13:
-                    //__do_next = false;
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 1, [COMPONENT.CONST.BTN_STATE.OFF] ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnActivateDistantSynchronizer( _timeout, "TEST_AUTO_1" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnUpdateDistantSynchronizer( _timeout, "TEST_AUTO_1" ) );
+                    __do_next = false;
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.forceImport( _timeout ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_PHASE.doNextWhen( _timeout, 'MANAGER.__instance_source_distributor.findSource("' + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER + '").fully_merged' ) );
+                    
                     break;
                 case 14:
-                    //__do_next = false;
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.delete( _timeout ) );
-                    break;
-                case 15:
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
-                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 0, [] ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-detail-last-run" ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerListLength( _timeout, 0 ) );
                     break;
             }
             break;
@@ -310,7 +293,7 @@ var doActionWhenReadyTestAuto = function () {
         
         case "00130":
             if ( !SHINKEN.TOOLS.ENCRYPTION.isProtectedFieldsActivated() ) {
-                console.warn( "GREG", "[00124]", "Ce test ne peut se faire que si le chiffrement est activé" );
+                console.warn( "GREG", "[00130]", "Ce test ne peut se faire que si le chiffrement est activé" );
                 break;
             }
             ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
@@ -710,6 +693,7 @@ var doActionWhenReadyTestAuto = function () {
                     ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.WORKING_AREA ) );
+                    _timeout += 2000; //NEEDED TO COMPUTE THE CHANGE
                     ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step4ToStep3( _timeout ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.currentStep( _timeout, 4 ) );
@@ -722,7 +706,6 @@ var doActionWhenReadyTestAuto = function () {
                     ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                     break;
                 case 2:
-                    __do_next = false;
                     ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT_EDITION.ACTION.navigateInTab( _timeout, WINDOW.CONST.ELEMENT.USER_RIGHTS ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACTS, "test_auto_valid" ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_MULTI_SELECT.ACTION.setBtnPlus( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, COMPONENT.CONST.BTN_STATE.ON ) );
@@ -808,27 +791,30 @@ var doActionWhenReadyTestAuto = function () {
         case "00204":  //CHECK XSS INJECTION ON ANALYSER CONFIGURATION PANEL
             switch ( __phase ) {
                 case 1:
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.switchSourceActivity( _timeout, SOURCE__NAME__SERVER__ANALYZER, true ) );
+                    break;
+                case 2:
                     __do_next = false;
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.setConfiguration( _timeout, "linux__login", SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.ACTION.submitForm( _timeout ) );
                     break;
-                case 2:
+                case 3:
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-network-scan" ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.deleteIpRangeByRequest( _timeout, [200, 400], false, "00204-1" ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.clickOnAddNetworkRange( _timeout ) );
                     __do_next = false;
                     break;
-                case 3:
+                case 4:
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.FORM.setValue( _timeout, "discovery_name", "test_auto_204" ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.FORM.setValue( _timeout, "iprange", SHINKEN.HIGHWAY.getHostName() ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.FORM.save( _timeout ) );
                     __do_next = false;
                     break;
-                case 4:
+                case 5:
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.clickOnAnalyzerButton( _timeout, "test_auto_204" ) );
                     __do_next = false;
                     break;
-                case 5:
+                case 6:
                     ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.clickOnLaunchAnalyzeButton( _timeout ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_XSS.isFunctionExisting( _timeout ) );
                     break;
@@ -859,6 +845,46 @@ var doActionWhenReadyTestAuto = function () {
         case "00232":  //SEF-9785
             ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.TEST.ifCodeIsPresent( _timeout, "after_scheduler_configuration_load", "/daemons/schedulerdaemon.py" ) );
             break;
+        case "00237": //SEF-10733
+            var _error = function ( err ) {
+                SHINKEN.TOOLS.TEST_AUTO.addError( err );
+                SHINKEN.TOOLS.TEST_AUTO.addError( "IS SERVER FLASK RUNNING ??" );
+            };
+            switch ( __phase ) {
+                case 1 :
+                    ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.TEST.fileNotExist( _timeout, "/var/lib/shinken/libexec/analyzer/impacket/examples/secretsdump.py", false, _error ) );
+                    break;
+                case 2 :
+                    ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.TEST.fileNotExist( _timeout, "/var/lib/shinken/libexec/analyzer/impacket/examples/secretsdump.pyo", false, _error ) );
+                    break;
+            }
+            break;
+        case "00238" :
+            switch ( __phase ) {
+                case 1 :
+                    if ( MANAGER.__instance_element_distributor.current_user.uuid !== '33000000000000000000000000000000' ) {
+                        SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_admin_si", "test_auto_admin_si" );
+                    }
+                    _timeout += 4000;
+                    break;
+                case 2 :
+                    var _navigator = window.open( SHINKEN.HIGHWAY.getPath(), "test", "width=" + window.innerWidth / 1.2 + ",height=" + window.innerHeight / 1.2 );
+                    
+                    _timeout += 3000;
+                    setTimeout( function () {
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, SHINKEN.TOOLS.TEST_AUTO_UI_CONFIGURATION_MENU.DOM.btnProduction( _navigator ) ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.TEST.redirect( _timeout, _navigator.location.pathname, "/main" ) );
+                    }, _timeout );
+                    setTimeout( function () {
+                        _navigator.close();
+                    }, _timeout + 2000 );
+                    break;
+                case 3 :
+                    SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
+                    _timeout += 4000;
+                    break;
+            }
+            break;
         case "go":
         case "00000":
             __shinken_test_type = "00000";
@@ -879,6 +905,7 @@ var doActionWhenReadyTestAuto = function () {
                     ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.TEST.isSourceExisting( _timeout, SOURCE__NAME__CFG_FILE_SHINKEN ) );
                     break;
                 case 6:
+                    ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "admin", "admin" ) );
                     ____( SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.dropAllDatabases( _timeout ) );
                     break;
                 case 7:
@@ -887,7 +914,7 @@ var doActionWhenReadyTestAuto = function () {
                 case 11:
                     break;
                 case 12:
-                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.ACTION.addConfiguration( _timeout, SOURCE.CONST.TYPES.LISTENER, "Shinken", "Shinken" ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.ACTION.addConfiguration( _timeout, SOURCE.CONST.TYPES.LISTENER, "Shinken", "Shinken", "SHINKEN.TOOLS.TEST_AUTO.buildMessage( 0 )" ) );
                     __do_next = false;
                     break;
                 case 13:
@@ -917,12 +944,9 @@ var doActionWhenReadyTestAuto = function () {
                     _timeout += 4000;
                     break;
                 case 21:
-                    if ( __version_shinken !== SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
-                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.addModuleIfNotSet( _timeout, "/etc/shinken/modules/webui.cfg", "webui-module-service-weather" ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.upsertDocumentToMongo( _timeout, "webui", "service_weather__weather_data", SHINKEN.TOOLS.TEST_AUTO.WEATHER_DEFAULT_UUID, SHINKEN.TOOLS.TEST_AUTO.WEATHER_DEFAULT_MONGO_DOCUMENT ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.BROKER.ACTION.restart( _timeout, false ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.ARBITER.ACTION.restart( _timeout, false ) );
-                    }
+                    _timeout += 4000;
+                    ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.TEST.activateWeatherModule( _timeout ) );
+                    ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.restart( _timeout ) );
                     break;
             }
             break;
@@ -951,7 +975,9 @@ var doActionWhenReadyTestAuto = function () {
             break;
         
     }
-    SHINKEN.TOOLS.TEST_AUTO.MakeFinalAction( _timeout );
+    if ( !__window_phase ) {
+        SHINKEN.TOOLS.TEST_AUTO.MakeFinalAction( _timeout );
+    }
 };
 
 
