@@ -15,7 +15,6 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                 switch ( __phase ) {
                     case 1:
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.visibility( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getMenu(), "barre du menu", true ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.userNameLabel( _timeout, 'test_auto_user_executor' ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.logout( _timeout ) );
                         break;
@@ -28,6 +27,7 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                         break;
                     case 3:
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.visibility( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getMenu(), "barre du menu", true ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.userNameLabel( _timeout, 'test_auto_user_executor' ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasStyle( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getMenu(), "height", 63, "barre du menu" ) );
                         break;
                     case 4:
@@ -95,9 +95,6 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                 }
                 break;
             case "00196": //NAVIGATION
-                if ( CONTROLLER.UiVisualisation.current_user.uuid !== '35000000000000000000000000000000' ) {
-                    alert( "test_auto_user_executor pas défini ==> relancer le test après avoir changé l'utilisateur" );
-                }
                 switch ( __phase ) {
                     case 1:
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, "shinken-extra-menu-cell" ) );
@@ -128,110 +125,114 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.VIEW360 ) );
                         break;
                     case 4: //COLLAPSED MENU
-                        SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator = window.open( SHINKEN.HIGHWAY.getPathOrigin(), "test", "width=" + window.innerWidth + ",height=" + window.innerHeight );
-                        _timeout                                                     = 3000; //WAITING THE TIME THAT THE NAVIGATOR POP
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.displayState( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.CONST.STATE_DISPLAY.VISIBLE, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO.ACTION.do_JS_action( _timeout, "SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator.resizeTo(1000," + window.innerHeight + ")", 500 ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.displayState( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.CONST.STATE_DISPLAY.VISIBLE_AND_COLLAPSE, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.openFull( _timeout, SHINKEN.HIGHWAY.getPathOrigin() ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.displayState( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.CONST.STATE_DISPLAY.VISIBLE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO.ACTION.do_JS_action( _timeout, "SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.instance.resizeTo(1000," + window.innerHeight + ")", 500 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.displayState( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.CONST.STATE_DISPLAY.VISIBLE_AND_COLLAPSE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                         
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, "shinken-collapsed-menu-cell", SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_list_all", SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.LIST, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_list_event", SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.EVENT, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_new_service_weather", SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_360", SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.VIEW360, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_impacts", SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.IMPACTS, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_reporting", SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.REPORTING, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_default_hive", SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.HIVE, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO.ACTION.do_JS_action( _timeout, "SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN._instance_navigator.close()", 500 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, "shinken-collapsed-menu-cell", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_list_all", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.LIST, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_list_event", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.EVENT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_new_service_weather", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_360", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.VIEW360, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_impacts", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.IMPACTS, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_reporting", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.REPORTING, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_default_hive", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.HIVE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.close( _timeout ) );
                         break;
                 }
                 break;
             case "00197": //LICENCE
                 switch ( __phase ) {
                     case 1:
-                        _timeout += 2000;
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NO_LICENCE ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NO_LICENCE ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.IS_DUPLICATED_TRIAL ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.IS_DUPLICATED_TRIAL ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.INVALID_FORMAT ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.INVALID_FORMAT ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LICENSE_EXPIRED ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LICENSE_EXPIRED ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.TESTING_VERSION ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.TESTING_VERSION ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_NODE_LIMIT_EXCEEDED ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_NODE_LIMIT_EXCEEDED ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" ) );
                         break;
                     case 2:
-                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor_si", "test_auto_user_executor_si" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.openFull( _timeout, SHINKEN.HIGHWAY.getPathOrigin() ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NO_LICENCE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NO_LICENCE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.IS_DUPLICATED_TRIAL, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.IS_DUPLICATED_TRIAL, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.INVALID_FORMAT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.INVALID_FORMAT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LICENSE_EXPIRED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LICENSE_EXPIRED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.TESTING_VERSION, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.TESTING_VERSION, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.close( _timeout ) );
                         break;
                     case 3:
-                        _timeout += 1500;
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.TESTING_VERSION ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_7_DAYS ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_7_DAYS ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NO_LICENCE ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NO_LICENCE ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.IS_DUPLICATED_TRIAL ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.IS_DUPLICATED_TRIAL ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.INVALID_FORMAT ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.INVALID_FORMAT ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LICENSE_EXPIRED ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LICENSE_EXPIRED ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED ) );
-                        
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_NODE_LIMIT_EXCEEDED ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor_si", "test_auto_user_executor_si" ) );
                         break;
                     case 4:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.openFull( _timeout, SHINKEN.HIGHWAY.getPathOrigin() ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.TESTING_VERSION, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_7_DAYS, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_7_DAYS, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NO_LICENCE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NO_LICENCE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.IS_DUPLICATED_TRIAL, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.IS_DUPLICATED_TRIAL, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.INVALID_FORMAT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.INVALID_FORMAT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LICENSE_EXPIRED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LICENSE_EXPIRED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.close( _timeout ) );
+                        break;
+                    case 5:
                         ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" ) );
                         break;
                     
@@ -448,6 +449,8 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.saveWithButtonSave( _timeout ) );
                         __do_next = false;
                         break;
+                    case 12:
+                        break;
                     case 13:
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.labelPropertyDiffPopup( _timeout, "00000000000000000000000000000233", PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                         break;
@@ -459,13 +462,21 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.labelPropertyDiff( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                         break;
                     case 16:
-                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.WORKING_AREA ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.saveWithButtonDifference( _timeout ) );
                         __do_next = false;
                         break;
                     case 17:
-                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.saveWithButtonSubmitToStagging( _timeout ) );
-                        __do_next = false;
+                        // TODO A refaire
+                        var _navigator = window.open( SHINKEN.HIGHWAY.getPath(), "test", "width=" + window.innerWidth / 1.2 + ",height=" + window.innerHeight / 1.2 );
+                        _timeout += 4000;
+                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.saveWithButtonSubmitToStagging( _timeout, _navigator ) );
+                        setTimeout( function () {
+                            _navigator.close();
+                        }, _timeout + 3000 );
+                        
+                        break;
+                    case 18:
                         break;
                     case 19:
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.labelPropertyProposedPopup( _timeout, "00000000000000000000000000000233", PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
@@ -474,7 +485,14 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.labelPropertyPropose( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                         break;
                     case 21:
-                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.saveWithButtonAcceptPropose( _timeout ) );
+                        // TODO A refaire
+                        var _navigator = window.open( SHINKEN.HIGHWAY.getPath(), "test", "width=" + window.innerWidth / 1.2 + ",height=" + window.innerHeight / 1.2 );
+                        _timeout += 3000;
+                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.saveWithButtonAcceptPropose( _timeout, _navigator ) );
+                        setTimeout( function () {
+                            _navigator.close();
+                        }, _timeout + 4000 );
+                        
                         break;
                 }
                 break;
@@ -488,13 +506,26 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.removeFileIfExists( _timeout, _default_properties_configuration_path ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.restart( _timeout, "synchronizer", false ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.restart( _timeout, "arbiter", false ) );
+                        _timeout += 10000; // Wait the restart of Webui module
                         break;
                     case 2:
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.addExtraColumn( _timeout, PROPERTY.CONST.NAME.NOTE_URL ) );
                         break;
                     case 3:
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.labelColumnHeader( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
-                        __do_next = false;
+                        break;
+                    case 4:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.LIST, "menu_expand_list_all" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LIST_ALL.TEST.columnHeaderLabel( _timeout, "notes_url_for_list", "Url externe" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LIST_ALL.TEST.headerManagerSubMenuListColumnLabel( _timeout, "notes_url_for_list", "Url externe" ) );
+                        break;
+                    case 5:
+                        _timeout += 2000; // Wait for loading page
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ELEMENT_DETAIL.TEST.labelCommandButton( _timeout, "openNotesUrl", "Ouvrir l'URL externe" ) );
+                        break;
+                    case 6:
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ELEMENT_DETAIL.TEST.labelCommandButton( _timeout, "openNotesUrl", "Ouvrir l'URL externe" ) );
+                        //__do_next = false;
                         break;
                 }
                 break;
@@ -522,7 +553,6 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                     case 6:
                         _timeout += 1000;
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getAddToFavoriteButton() ) );
-                        __do_next = false;
                         break;
                 }
                 break;
