@@ -3,13 +3,11 @@
 SHINKEN_LIST.PaginationFromData = function ( type ) {
     this.__class_name__ = "SHINKEN_LIST.PaginationFromData";
     this.type           = type;
-    console.log('[BMDEV] going init:〖', 'going init' ,'〗')
     this.initSpecific();
 };
 
 SHINKEN_LIST.PaginationFromData.prototype = {
     initSpecific: function () {
-        console.log('[BMDEV] PaginationFromData:〖', 'PaginationFromData' ,'〗')
         this.init();
     },
     
