@@ -11,8 +11,13 @@ SHINKEN.TOOLS.UpdateAtComponent.prototype = {
     
     //********************************************  GETTER SETTER  *****************************************************//
     setLastComputeDate: function ( to_set ) {
-        this.dom_element_date.innerHTML = DATE_TIME.FORMAT.get_time_from_timestamp( to_set );
-    },
+        if ( !to_set ) {
+            this.dom_element_date.innerHTML = _( 'service_weather.generate_at.generation_in_progress', [DICTIONARY_COMMON_UI] );
+        }
+        else {
+            this.dom_element_date.innerHTML = DATE_TIME.FORMAT.get_time_from_timestamp( to_set );
+        }
+    }
     //********************************************  HTML  *****************************************************//
     //********************************************  COMPUTE  *****************************************************//
     //********************************************  EVENT REFRESH  *****************************************************//
