@@ -231,6 +231,11 @@ class AbstractDataHubDriverFile(AbstractDataHubDriver):
         shutil.rmtree(self._data_folder)
     
     
+    def stop(self):
+        # type: () -> None
+        pass
+    
+    
     def get_total_size(self):
         # type: () -> int
         total_size = 0
