@@ -100,6 +100,15 @@ def get_datetime_from_utc_to_local_time_zone(_datetime):
     return _datetime.replace(tzinfo=TZINFO_UTC).astimezone(TZINFO_LOCAL)
 
 
+def get_datetime_from_local_to_utc_time_zone(_datetime):
+    # type: (datetime) -> datetime
+    return _datetime.replace(tzinfo=TZINFO_LOCAL).astimezone(TZINFO_UTC)
+
+
+def get_datetime_now_as_utc():
+    return datetime.fromtimestamp(get_now(), tz=TZINFO_UTC)
+
+
 class DATE_COMPARE(object):
     IS_BEFORE = -1
     IS_AFTER = 1
