@@ -8,30 +8,30 @@ import os
 from collections import OrderedDict, namedtuple
 
 from shinken.exceptions.business import ShinkenExceptionKeyError
+from shinken.log import LoggerFactory
 from shinken.misc.type_hint import TYPE_CHECKING
 from shinken.util import WeakMethod
 
 if TYPE_CHECKING:
-    from shinken.misc.type_hint import Optional, List, Any, Union
+    from shinken.misc.type_hint import Optional, List, Any, Union, Dict, Iterable, Tuple
     from shinken.log import PartLogger
     from shinken.objects.module import Module as ShinkenModuleDefinition
 
 HIDDEN_LOG_CONTENT = u'-*- hidden -*-'
 
-ConfigurationFormat = namedtuple('ConfigurationFormat', ['configuration_key', 'default_value', 'key_type', 'prop_name'])
+ConfigurationFormat = namedtuple('ConfigurationFormat', ['configuration_keys', 'default_value', 'key_type', 'prop_name'])
 
 
 # USAGE of ConfigurationFormat :
 #
-# configuration_key is Union[unicode, List[unicode]]
-#  * unicode  Ex: u'parameter_name' for a normal lookup of parameter in conf file
+# configuration_keys is List[unicode]
 #  * list of unicode  Ex: [u'old_parameter_name', u'very_old_parameter_name', u'parameter_name']
-#  ==> In this case, list entries are looked for in conf file in list order, last value found replace previous ones,
+#  ==> list entries are looked for in conf file in list order, last value found replace previous ones,
 #  ==> log will use last list entry as the name for this parameter
 #
 # key_type from TypeConfiguration class. Special type HIDDEN_XXX will not print clear data in log file
 #
-# prop_name is Optional[unicode], if not empty, will settattr self.prop_name with value from conf, else value will only be printed in log
+# prop_name is Optional[unicode], if not empty, will setattr self.prop_name with value from conf, else value will only be printed in log
 
 
 class TypeConfiguration(object):
@@ -49,23 +49,38 @@ class SeparatorFormat(object):
     def __init__(self, value):
         self.prop_name = value
         self.default_value = value
-        self.configuration_key = value
+        self.configuration_keys = list(value)
         self.key_type = TypeConfiguration.SEPARATOR
     
     
     def __iter__(self):
-        return iter((self.configuration_key, self.default_value, self.key_type, self.prop_name))
+        return iter((self.configuration_keys, self.default_value, self.key_type, self.prop_name))
 
 
 class ConfigurationReaderMixin(object):
     def __init__(self, configuration_format, configuration, logger=None):
-        # type:(List[ConfigurationFormat], ShinkenModuleDefinition, Optional[PartLogger]) -> None
-        self._configuration_format = configuration_format
+        # type:(List[Union[ConfigurationFormat,SeparatorFormat]], ShinkenModuleDefinition, Optional[PartLogger]) -> None
+        self._configuration_format = []
         self._configuration = configuration
         self._logger = logger
         self._configuration_error = {}
         self._configuration_load = OrderedDict()
         
+        for element in configuration_format:
+            if isinstance(element, SeparatorFormat):
+                self._configuration_format.append(element)
+            elif not isinstance(element, ConfigurationFormat):
+                if logger:
+                    logger.error(u'wrong configuration parameter format ignored ( %s )' % element)
+                continue
+            # Compatibility : configuration_key was unicode, now we want a list of unicode
+            if logger and not isinstance(element.configuration_keys, list):
+                logger.warning(u'Wrong format for configuration_keys parameter, backward compatibility enabled for key:[%s]' % element.configuration_keys)
+            self._configuration_format.append(ConfigurationFormat(configuration_keys=element.configuration_keys if isinstance(element.configuration_keys, list) else [element.configuration_keys],
+                                                                  default_value=element.default_value,
+                                                                  key_type=element.key_type,
+                                                                  prop_name=element.prop_name))
+        
         self._readers = {
             TypeConfiguration.BOOL         : WeakMethod(self.read_bool_in_configuration),
             TypeConfiguration.INT          : WeakMethod(self.read_int_in_configuration),
@@ -79,11 +94,11 @@ class ConfigurationReaderMixin(object):
     
     def read_configuration(self):
         # type: () -> OrderedDict
-        for configuration_key, default_value, key_type, prop_name in self._configuration_format:
+        for configuration_keys, default_value, key_type, prop_name in self._configuration_format:
             if key_type == TypeConfiguration.SEPARATOR:
-                self._configuration_load[''.join((TypeConfiguration.SEPARATOR, configuration_key))] = (u'', default_value)
+                self._configuration_load[''.join((TypeConfiguration.SEPARATOR, default_value))] = (u'', default_value)
             else:
-                key_name, val = self._parse_keys(configuration_key, default_value, key_type, prop_name)
+                key_name, val = self._parse_keys(configuration_keys, default_value, key_type, prop_name)
                 if prop_name:
                     setattr(self, prop_name, val)
                 if key_type in [TypeConfiguration.HIDDEN_STRING]:
@@ -93,47 +108,56 @@ class ConfigurationReaderMixin(object):
         return self._configuration_load
     
     
-    def _parse_keys(self, configuration_key, default_value, key_type, prop_name):
+    def _parse_keys(self, configuration_keys, default_value, key_type, prop_name):
         # type: (Union[List, unicode], Any, unicode, Optional[unicode]) -> (unicode, Any)
-        if isinstance(configuration_key, list):
-            val = default_value
-            key_name = u''
-            for conf_key in configuration_key:
-                def_value = val
-                key_name = conf_key
-                val = self._readers[key_type](conf_key, def_value)
-        else:
-            val = self._readers[key_type](configuration_key, default_value)
-            key_name = configuration_key
+        conf_has_been_computed_in_arbiter = hasattr(self._configuration, u'module_info_json')
+        if conf_has_been_computed_in_arbiter:
+            val = getattr(self._configuration, prop_name, None)
+            key_name = configuration_keys[-1]
+            configuration_reading_errors_from_arbiter = getattr(self._configuration, u'configuration_reading_errors', None)
+            if configuration_reading_errors_from_arbiter and key_name in configuration_reading_errors_from_arbiter:
+                # Generate log, and store error data
+                self.handle_error(key_name, value=configuration_reading_errors_from_arbiter[key_name][u'conf_value'], default_value=configuration_reading_errors_from_arbiter[key_name][u'default_value'])
+            return key_name, val
+        
+        val = default_value
+        key_name = u''
+        for conf_key in configuration_keys:
+            def_value = val
+            key_name = conf_key
+            val = self._readers[key_type](conf_key, def_value)
         if not key_name:
-            raise ShinkenExceptionKeyError(text=u'Configuration (key:[ %s ] default:[ %s ] type:[ %s ] property_name:[ %s ]) has wrong key name' % (configuration_key, default_value, key_type, prop_name))
+            raise ShinkenExceptionKeyError(text=u'Configuration (keys[ %s ] default:[ %s ] type:[ %s ] property_name:[ %s ]) has wrong key name' % (configuration_keys, default_value, key_type, prop_name))
         return key_name, val
     
     
     def add_separator(self, prop_name):
+        # type: (unicode) -> None
         self._configuration_load[''.join((TypeConfiguration.SEPARATOR, prop_name))] = (u'', prop_name)
     
     
     def read_prop(self, prop_name):
+        # type: (unicode) -> None
         conf = next((i for i in self._configuration_format if i.prop_name == prop_name), None)
         if not conf:
             self._logger.error(u'The prop 〖 %s 〗 is not known by the module configuration' % prop_name)
             return None
-        configuration_key, default_value, key_type, prop_name = conf
+        configuration_keys, default_value, key_type, prop_name = conf
         if key_type == TypeConfiguration.SEPARATOR:
-            self._configuration_load[''.join((TypeConfiguration.SEPARATOR, configuration_key))] = (u'', default_value)
+            self._configuration_load[''.join((TypeConfiguration.SEPARATOR, default_value))] = (u'', default_value)
         else:
-            key_name, val = self._parse_keys(configuration_key, default_value, key_type, prop_name)
+            key_name, val = self._parse_keys(configuration_keys, default_value, key_type, prop_name)
             self._configuration_load[key_name] = (prop_name, val)
             return val
     
     
     def reset_prop_with_wrong_value(self, prop_name):
+        # type: (unicode) -> None
         conf_data = next((configuration for configuration in self._configuration_format if getattr(configuration, u'prop_name', u'') == prop_name), None)
         if not conf_data:
             return
         
-        key_name = conf_data.configuration_key
+        key_name = conf_data.configuration_keys
         if isinstance(key_name, list):
             key_name = key_name[-1]
         cur_value = getattr(self, prop_name, None)
@@ -154,6 +178,7 @@ class ConfigurationReaderMixin(object):
     
     
     def log_configuration(self, log_properties=False, show_values_as_in_conf_file=False):
+        # type: (bool,bool) -> None
         line_length = max([len(kn) for kn in self._configuration_load.keys()]) + 2
         for key_name, value in self._configuration_load.items():
             if key_name.startswith(TypeConfiguration.SEPARATOR):
@@ -258,10 +283,12 @@ class ConfigurationReaderMixin(object):
     
     
     def get_logger(self):
+        # type: () -> PartLogger
         return self._logger
     
     
     def after_fork_cleanup(self):
+        # type: () -> None
         self._logger = None
         self._configuration = None
         self._configuration_format = None
@@ -270,6 +297,18 @@ class ConfigurationReaderMixin(object):
         self._readers = None
     
     
+    def get_properties_from_loaded_configuration(self):
+        # type: () -> List[Optional[Tuple[unicode,Any,None]]]
+        properties_list = []
+        for prop_name, _ in self._configuration_load.itervalues():
+            # LoggerFactory.get_logger().get_sub_part('CONFIGURATION').get_sub_part('MODULE INFO').debug(u'%s PROP:%s VAL:%s' % (getattr(self._configuration, 'module_name', 'NO NAME MODULE'), prop_name, getattr(self, prop_name) if prop_name else u'--'))
+            
+            if not prop_name:
+                continue
+            properties_list.append((prop_name, getattr(self, prop_name), None))
+        return properties_list
+    
+    
     @staticmethod
     def configuration_format_jsonify(configuration_format):
         # type: (List) -> unicode
@@ -283,6 +322,19 @@ class ConfigurationReaderMixin(object):
         return json.dumps(configuration_format, cls=ConfigurationFormatEnc)
     
     
+    @staticmethod
+    def get_broker_name_from_arbiter_configuration(configuration):
+        # type: (ShinkenModuleDefinition) -> unicode
+        broker_name = u'broker'
+        if hasattr(configuration, u'father_config'):
+            broker_name = configuration.father_config.get(u'broker_name', broker_name)
+        if not broker_name.startswith(u'shinken'):
+            broker_name = u'shinken-%s' % broker_name
+        return broker_name
+
+
+class ConfigurationReader(ConfigurationReaderMixin):
+    
     @staticmethod
     def configuration_format_from_loaded_json(configuration_list, logger=None):
         # type: (List, Optional[PartLogger]) -> List
@@ -300,24 +352,90 @@ class ConfigurationReaderMixin(object):
                 if logger:
                     logger.error(u'wrong configuration parameter format ignored ( %s )' % element)
                 continue
-            configuration_format.append(ConfigurationFormat(*element))
+            configuration_format.append(ConfigurationFormat(configuration_keys=element[0] if isinstance(element[0], list) else [element[0]],
+                                                            default_value=element[1],
+                                                            key_type=element[2],
+                                                            prop_name=element[3]))
         
         return configuration_format
     
     
     @staticmethod
-    def configuration_update_from_module_info(configuration, standard_configuration_parameters_def=None):
-        # type: (ShinkenModuleDefinition, Optional[List]) -> Union[ConfigurationReaderMixin,ShinkenModuleDefinition]
-        try:
-            if not standard_configuration_parameters_def:
-                module_info_path = os.path.join(getattr(configuration, u'modules_dir', u'/var/lib/shinken/modules'), u'graphite', u'module_info.json')
-                with open(module_info_path, u'r') as fd:
-                    module_info = json.load(fd)
-                standard_configuration_parameters_def = ConfigurationReaderMixin.configuration_format_from_loaded_json(module_info.get(u'standard_configuration_parameters', None))
-            if standard_configuration_parameters_def:
-                module = ConfigurationReaderMixin(standard_configuration_parameters_def, configuration)
-                module.read_configuration()
-                return module, standard_configuration_parameters_def
-        except:
-            pass
-        return configuration, None
+    def load_all_modules_infos(modules_dir, modules_logger):
+        # type: (unicode, PartLogger) -> Dict[unicode,Dict]
+        if not os.path.isdir(modules_dir):
+            modules_logger.warning(u'[ %s ] is not a directory' % modules_dir)
+            return {}
+        modules_list = [module_dir_name for module_dir_name in os.listdir(modules_dir) if os.path.isdir(os.path.join(modules_dir, module_dir_name))]
+        all_modules_info = {}
+        already_load_module_info = {}
+        for module_dir in modules_list:
+            module_info_path = os.path.join(modules_dir, module_dir, u'module_info.json')
+            if os.path.isfile(module_info_path):
+                try:
+                    with open(module_info_path) as json_file:
+                        module_info = json.load(json_file)
+                    
+                    module_types = set()
+                    
+                    if u'type' in module_info:
+                        module_types.add(module_info[u'type'])
+                    elif u'module_types_by_daemons' in module_info:
+                        for module_info_by_daemon in module_info[u'module_types_by_daemons']:
+                            module_type_by_daemon = module_info_by_daemon.get(u'module_type', None)
+                            if module_type_by_daemon:
+                                module_types.add(module_type_by_daemon)
+                    
+                    if not module_types:
+                        modules_logger.error(u'Missing "type" data in module_info.json in directory %s' % module_dir)
+                        continue
+                    for module_type in module_types:
+                        if module_type in all_modules_info:
+                            modules_logger.error(u'Ignoring duplicate module_info for module type %s found in directory %s and keeping data from directory %s' % (module_type, module_dir, already_load_module_info[module_type]))
+                            continue
+                        all_modules_info.update({module_type: module_info})
+                        already_load_module_info.update({module_type: module_dir})
+                except:
+                    modules_logger.print_stack()
+        return all_modules_info
+    
+    
+    @staticmethod
+    def update_all_modules_with_module_info(module_dir, modules):
+        # type: (unicode, Iterable[ShinkenModuleDefinition]) -> None
+        modules_logger = LoggerFactory.get_logger().get_sub_part(u'CONFIGURATION').get_sub_part(u'MODULE INFO')
+        
+        all_module_info = ConfigurationReader.load_all_modules_infos(module_dir, modules_logger)
+        if not all_module_info:
+            return
+        
+        for module in modules:
+            module_type = getattr(module, u'module_type', None)
+            if module_type not in all_module_info:
+                continue
+            
+            module_info = all_module_info[module_type]
+            configuration_errors = {}
+            updated_properties = []
+            
+            standard_parameter_format = ConfigurationReader.configuration_format_from_loaded_json(module_info.get(u'standard_configuration_parameters', None), logger=modules_logger)
+            if standard_parameter_format:
+                module_conf = ConfigurationReader(standard_parameter_format, module, logger=modules_logger)
+                module_conf.read_configuration()
+                updated_properties.extend(module_conf.get_properties_from_loaded_configuration())
+                configuration_errors.update(module_conf._configuration_error)
+            
+            mongo_parameter_format = module_info.get(u'mongodb_configuration_parameters_prefix', None)
+            if mongo_parameter_format:
+                # Import here to avoid cyclic import
+                from shinkensolutions.ssh_mongodb.mongo_conf import MongoConf
+                
+                module_conf = MongoConf(module, prefix_module_property=mongo_parameter_format, logger=modules_logger)
+                updated_properties.extend(module_conf.get_properties_from_loaded_configuration())
+                configuration_errors.update(module_conf._configuration_error)
+            
+            if updated_properties:
+                updated_properties.append((u'module_info_json', module_info, None))
+                if configuration_errors:
+                    updated_properties.append((u'configuration_reading_errors', configuration_errors, None))
+                module.set_some_properties(updated_properties)
