@@ -17,6 +17,8 @@ import uuid
 from StringIO import StringIO
 from hashlib import md5
 
+import psutil
+
 if os.name != 'nt':
     CONTEXT_PATH = '/var/lib/shinken/context.json'
 else:  # specific path for windows
@@ -36,7 +38,8 @@ RESET_SHELL_TAG = '\033[0m'
 
 if os.path.exists(CONTEXT_PATH):
     _context = json.loads(open(CONTEXT_PATH, 'r').read())
-    VERSION = str(_context.get('current_version', VERSION).split('-')[0])
+    VERSION = str(_context.get('current_version', VERSION).split(u'-')[0])
+    VERSION = VERSION.replace('.fr', '').replace('.us', '')
 
 # ENV variable to force unset at all cost
 unset_variables = ['http_proxy', 'https_proxy', 'ftp_proxy']
@@ -188,6 +191,45 @@ def _get_server_identity():
     return __get_server_identity()
 
 
+def __get_windows_server_identity():
+    # type: () -> unicode
+    macs = []
+    for interface_name, interface_info in psutil.net_if_addrs().iteritems():
+        interface_info = interface_info[0]
+        if interface_info.family == psutil.AF_LINK:
+            macs.append(interface_info.address)
+    mac_hash = md5(u''.join(sorted(macs))).hexdigest()
+    return u'sk-%s-%s' % (mac_hash, uuid.uuid4())
+
+
+def __get_linux_server_identity():
+    # type: () -> unicode
+    macs = []
+    product_uuid_path = u'/sys/class/dmi/id/product_uuid'
+    
+    if os.path.exists(product_uuid_path):
+        with open(product_uuid_path) as fp:
+            server_uuid = fp.readline().strip().lower()
+    else:
+        server_uuid_path = u'/var/lib/shinken/server.uuid'
+        if os.path.exists(server_uuid_path):
+            with open(server_uuid_path) as fp:
+                server_uuid = fp.readline().strip().lower()
+        else:
+            server_uuid = u''
+        for iface in os.listdir(u'/sys/class/net/'):
+            try:
+                with open(u'/sys/class/net/%s/address' % iface) as fp:
+                    macs.append(fp.readline().strip().lower())
+            except IOError:
+                # This interface doesn't have any HW address, just skip it
+                pass
+        mac_hash = md5(u''.join(sorted(macs))).hexdigest()
+        if server_uuid.count(u'-') == 0 or mac_hash != server_uuid.split(u'-')[1]:
+            server_uuid = u'sk-%s-%s' % (mac_hash, uuid.uuid4())
+    return server_uuid
+
+
 # returns the server identify so we know on which server it was installed before:
 # server_name = hostname of the server
 # server_uuid = bios uuid in lower, same as the arbiter one in the init.d script
@@ -198,28 +240,10 @@ def __get_server_identity():
     except Exception:
         server_name = u'unknown'
     try:
-        product_uuid_path = u'/sys/class/dmi/id/product_uuid'
-        if os.path.exists(product_uuid_path):
-            with open(product_uuid_path) as fp:
-                server_uuid = fp.readline().strip().lower()
+        if sys.platform.startswith(u'win'):
+            server_uuid = __get_windows_server_identity()
         else:
-            server_uuid_path = u'/var/lib/shinken/server.uuid'
-            if os.path.exists(server_uuid_path):
-                with open(server_uuid_path) as fp:
-                    server_uuid = fp.readline().strip().lower()
-            else:
-                server_uuid = u''
-            macs = []
-            for iface in os.listdir(u'/sys/class/net/'):
-                try:
-                    with open(u'/sys/class/net/%s/address' % iface) as fp:
-                        macs.append(fp.readline().strip().lower())
-                except IOError:
-                    # This interface doesn't have any HW address, just skip it
-                    pass
-            mac_hash = md5(u''.join(sorted(macs))).hexdigest()
-            if server_uuid.count(u'-') == 0 or mac_hash != server_uuid.split(u'-')[1]:
-                server_uuid = u'sk-%s-%s' % (mac_hash, uuid.uuid4())
+            server_uuid = __get_linux_server_identity()
     except Exception:
         traceback.print_exc()
         server_uuid = u'unknown'
